/* All the files in _merged have been merged in one file to speed up client downloads. */

/*  Prototype JavaScript framework, version 1.5.0
 *  (c) 2005-2007 Sam Stephenson
 *
 *  Prototype is freely distributable under the terms of an MIT-style license.
 *  For details, see the Prototype web site: http://prototype.conio.net/
 *
/*--------------------------------------------------------------------------*/

var Prototype = {
  Version: '1.5.0',
  BrowserFeatures: {
    XPath: !!document.evaluate
  },

  ScriptFragment: '(?:<script.*?>)((\n|\r|.)*?)(?:<\/script>)',
  emptyFunction: function() {},
  K: function(x) { return x }
}

var Class = {
  create: function() {
    return function() {
      this.initialize.apply(this, arguments);
    }
  }
}

var Abstract = new Object();

Object.extend = function(destination, source) {
  for (var property in source) {
    destination[property] = source[property];
  }
  return destination;
}

Object.extend(Object, {
  inspect: function(object) {
    try {
      if (object === undefined) return 'undefined';
      if (object === null) return 'null';
      return object.inspect ? object.inspect() : object.toString();
    } catch (e) {
      if (e instanceof RangeError) return '...';
      throw e;
    }
  },

  keys: function(object) {
    var keys = [];
    for (var property in object)
      keys.push(property);
    return keys;
  },

  values: function(object) {
    var values = [];
    for (var property in object)
      values.push(object[property]);
    return values;
  },

  clone: function(object) {
    return Object.extend({}, object);
  }
});

Function.prototype.bind = function() {
  var __method = this, args = $A(arguments), object = args.shift();
  return function() {
    return __method.apply(object, args.concat($A(arguments)));
  }
}

Function.prototype.bindAsEventListener = function(object) {
  var __method = this, args = $A(arguments), object = args.shift();
  return function(event) {
    return __method.apply(object, [( event || window.event)].concat(args).concat($A(arguments)));
  }
}

Object.extend(Number.prototype, {
  toColorPart: function() {
    var digits = this.toString(16);
    if (this < 16) return '0' + digits;
    return digits;
  },

  succ: function() {
    return this + 1;
  },

  times: function(iterator) {
    $R(0, this, true).each(iterator);
    return this;
  }
});

var Try = {
  these: function() {
    var returnValue;

    for (var i = 0, length = arguments.length; i < length; i++) {
      var lambda = arguments[i];
      try {
        returnValue = lambda();
        break;
      } catch (e) {}
    }

    return returnValue;
  }
}

/*--------------------------------------------------------------------------*/

var PeriodicalExecuter = Class.create();
PeriodicalExecuter.prototype = {
  initialize: function(callback, frequency) {
    this.callback = callback;
    this.frequency = frequency;
    this.currentlyExecuting = false;

    this.registerCallback();
  },

  registerCallback: function() {
    this.timer = setInterval(this.onTimerEvent.bind(this), this.frequency * 1000);
  },

  stop: function() {
    if (!this.timer) return;
    clearInterval(this.timer);
    this.timer = null;
  },

  onTimerEvent: function() {
    if (!this.currentlyExecuting) {
      try {
        this.currentlyExecuting = true;
        this.callback(this);
      } finally {
        this.currentlyExecuting = false;
      }
    }
  }
}
String.interpret = function(value){
  return value == null ? '' : String(value);
}

Object.extend(String.prototype, {
  gsub: function(pattern, replacement) {
    var result = '', source = this, match;
    replacement = arguments.callee.prepareReplacement(replacement);

    while (source.length > 0) {
      if (match = source.match(pattern)) {
        result += source.slice(0, match.index);
        result += String.interpret(replacement(match));
        source  = source.slice(match.index + match[0].length);
      } else {
        result += source, source = '';
      }
    }
    return result;
  },

  sub: function(pattern, replacement, count) {
    replacement = this.gsub.prepareReplacement(replacement);
    count = count === undefined ? 1 : count;

    return this.gsub(pattern, function(match) {
      if (--count < 0) return match[0];
      return replacement(match);
    });
  },

  scan: function(pattern, iterator) {
    this.gsub(pattern, iterator);
    return this;
  },

  truncate: function(length, truncation) {
    length = length || 30;
    truncation = truncation === undefined ? '...' : truncation;
    return this.length > length ?
      this.slice(0, length - truncation.length) + truncation : this;
  },

  strip: function() {
    return this.replace(/^\s+/, '').replace(/\s+$/, '');
  },

  stripTags: function() {
    return this.replace(/<\/?[^>]+>/gi, '');
  },

  stripScripts: function() {
    return this.replace(new RegExp(Prototype.ScriptFragment, 'img'), '');
  },

  extractScripts: function() {
    var matchAll = new RegExp(Prototype.ScriptFragment, 'img');
    var matchOne = new RegExp(Prototype.ScriptFragment, 'im');
    return (this.match(matchAll) || []).map(function(scriptTag) {
      return (scriptTag.match(matchOne) || ['', ''])[1];
    });
  },

  evalScripts: function() {
    return this.extractScripts().map(function(script) { return eval(script) });
  },

  escapeHTML: function() {
    var div = document.createElement('div');
    var text = document.createTextNode(this);
    div.appendChild(text);
    return div.innerHTML;
  },

  unescapeHTML: function() {
    var div = document.createElement('div');
    div.innerHTML = this.stripTags();
    return div.childNodes[0] ? (div.childNodes.length > 1 ?
      $A(div.childNodes).inject('',function(memo,node){ return memo+node.nodeValue }) :
      div.childNodes[0].nodeValue) : '';
  },

  toQueryParams: function(separator) {
    var match = this.strip().match(/([^?#]*)(#.*)?$/);
    if (!match) return {};

    return match[1].split(separator || '&').inject({}, function(hash, pair) {
      if ((pair = pair.split('='))[0]) {
        var name = decodeURIComponent(pair[0]);
        var value = pair[1] ? decodeURIComponent(pair[1]) : undefined;

        if (hash[name] !== undefined) {
          if (hash[name].constructor != Array)
            hash[name] = [hash[name]];
          if (value) hash[name].push(value);
        }
        else hash[name] = value;
      }
      return hash;
    });
  },

  toArray: function() {
    return this.split('');
  },

  succ: function() {
    return this.slice(0, this.length - 1) +
      String.fromCharCode(this.charCodeAt(this.length - 1) + 1);
  },

  camelize: function() {
    var parts = this.split('-'), len = parts.length;
    if (len == 1) return parts[0];

    var camelized = this.charAt(0) == '-'
      ? parts[0].charAt(0).toUpperCase() + parts[0].substring(1)
      : parts[0];

    for (var i = 1; i < len; i++)
      camelized += parts[i].charAt(0).toUpperCase() + parts[i].substring(1);

    return camelized;
  },

  capitalize: function(){
    return this.charAt(0).toUpperCase() + this.substring(1).toLowerCase();
  },

  underscore: function() {
    return this.gsub(/::/, '/').gsub(/([A-Z]+)([A-Z][a-z])/,'#{1}_#{2}').gsub(/([a-z\d])([A-Z])/,'#{1}_#{2}').gsub(/-/,'_').toLowerCase();
  },

  dasherize: function() {
    return this.gsub(/_/,'-');
  },

  inspect: function(useDoubleQuotes) {
    var escapedString = this.replace(/\\/g, '\\\\');
    if (useDoubleQuotes)
      return '"' + escapedString.replace(/"/g, '\\"') + '"';
    else
      return "'" + escapedString.replace(/'/g, '\\\'') + "'";
  }
});

String.prototype.gsub.prepareReplacement = function(replacement) {
  if (typeof replacement == 'function') return replacement;
  var template = new Template(replacement);
  return function(match) { return template.evaluate(match) };
}

String.prototype.parseQuery = String.prototype.toQueryParams;

var Template = Class.create();
Template.Pattern = /(^|.|\r|\n)(#\{(.*?)\})/;
Template.prototype = {
  initialize: function(template, pattern) {
    this.template = template.toString();
    this.pattern  = pattern || Template.Pattern;
  },

  evaluate: function(object) {
    return this.template.gsub(this.pattern, function(match) {
      var before = match[1];
      if (before == '\\') return match[2];
      return before + String.interpret(object[match[3]]);
    });
  }
}

var $break    = new Object();
var $continue = new Object();

var Enumerable = {
  each: function(iterator) {
    var index = 0;
    try {
      this._each(function(value) {
        try {
          iterator(value, index++);
        } catch (e) {
          if (e != $continue) throw e;
        }
      });
    } catch (e) {
      if (e != $break) throw e;
    }
    return this;
  },

  eachSlice: function(number, iterator) {
    var index = -number, slices = [], array = this.toArray();
    while ((index += number) < array.length)
      slices.push(array.slice(index, index+number));
    return slices.map(iterator);
  },

  all: function(iterator) {
    var result = true;
    this.each(function(value, index) {
      result = result && !!(iterator || Prototype.K)(value, index);
      if (!result) throw $break;
    });
    return result;
  },

  any: function(iterator) {
    var result = false;
    this.each(function(value, index) {
      if (result = !!(iterator || Prototype.K)(value, index))
        throw $break;
    });
    return result;
  },

  collect: function(iterator) {
    var results = [];
    this.each(function(value, index) {
      results.push((iterator || Prototype.K)(value, index));
    });
    return results;
  },

  detect: function(iterator) {
    var result;
    this.each(function(value, index) {
      if (iterator(value, index)) {
        result = value;
        throw $break;
      }
    });
    return result;
  },

  findAll: function(iterator) {
    var results = [];
    this.each(function(value, index) {
      if (iterator(value, index))
        results.push(value);
    });
    return results;
  },

  grep: function(pattern, iterator) {
    var results = [];
    this.each(function(value, index) {
      var stringValue = value.toString();
      if (stringValue.match(pattern))
        results.push((iterator || Prototype.K)(value, index));
    })
    return results;
  },

  include: function(object) {
    var found = false;
    this.each(function(value) {
      if (value == object) {
        found = true;
        throw $break;
      }
    });
    return found;
  },

  inGroupsOf: function(number, fillWith) {
    fillWith = fillWith === undefined ? null : fillWith;
    return this.eachSlice(number, function(slice) {
      while(slice.length < number) slice.push(fillWith);
      return slice;
    });
  },

  inject: function(memo, iterator) {
    this.each(function(value, index) {
      memo = iterator(memo, value, index);
    });
    return memo;
  },

  invoke: function(method) {
    var args = $A(arguments).slice(1);
    return this.map(function(value) {
      return value[method].apply(value, args);
    });
  },

  max: function(iterator) {
    var result;
    this.each(function(value, index) {
      value = (iterator || Prototype.K)(value, index);
      if (result == undefined || value >= result)
        result = value;
    });
    return result;
  },

  min: function(iterator) {
    var result;
    this.each(function(value, index) {
      value = (iterator || Prototype.K)(value, index);
      if (result == undefined || value < result)
        result = value;
    });
    return result;
  },

  partition: function(iterator) {
    var trues = [], falses = [];
    this.each(function(value, index) {
      ((iterator || Prototype.K)(value, index) ?
        trues : falses).push(value);
    });
    return [trues, falses];
  },

  pluck: function(property) {
    var results = [];
    this.each(function(value, index) {
      results.push(value[property]);
    });
    return results;
  },

  reject: function(iterator) {
    var results = [];
    this.each(function(value, index) {
      if (!iterator(value, index))
        results.push(value);
    });
    return results;
  },

  sortBy: function(iterator) {
    return this.map(function(value, index) {
      return {value: value, criteria: iterator(value, index)};
    }).sort(function(left, right) {
      var a = left.criteria, b = right.criteria;
      return a < b ? -1 : a > b ? 1 : 0;
    }).pluck('value');
  },

  toArray: function() {
    return this.map();
  },

  zip: function() {
    var iterator = Prototype.K, args = $A(arguments);
    if (typeof args.last() == 'function')
      iterator = args.pop();

    var collections = [this].concat(args).map($A);
    return this.map(function(value, index) {
      return iterator(collections.pluck(index));
    });
  },

  size: function() {
    return this.toArray().length;
  },

  inspect: function() {
    return '#<Enumerable:' + this.toArray().inspect() + '>';
  }
}

Object.extend(Enumerable, {
  map:     Enumerable.collect,
  find:    Enumerable.detect,
  select:  Enumerable.findAll,
  member:  Enumerable.include,
  entries: Enumerable.toArray
});
var $A = Array.from = function(iterable) {
  if (!iterable) return [];
  if (iterable.toArray) {
    return iterable.toArray();
  } else {
    var results = [];
    for (var i = 0, length = iterable.length; i < length; i++)
      results.push(iterable[i]);
    return results;
  }
}

Object.extend(Array.prototype, Enumerable);

if (!Array.prototype._reverse)
  Array.prototype._reverse = Array.prototype.reverse;

Object.extend(Array.prototype, {
  _each: function(iterator) {
    for (var i = 0, length = this.length; i < length; i++)
      iterator(this[i]);
  },

  clear: function() {
    this.length = 0;
    return this;
  },

  first: function() {
    return this[0];
  },

  last: function() {
    return this[this.length - 1];
  },

  compact: function() {
    return this.select(function(value) {
      return value != null;
    });
  },

  flatten: function() {
    return this.inject([], function(array, value) {
      return array.concat(value && value.constructor == Array ?
        value.flatten() : [value]);
    });
  },

  without: function() {
    var values = $A(arguments);
    return this.select(function(value) {
      return !values.include(value);
    });
  },

  indexOf: function(object) {
    for (var i = 0, length = this.length; i < length; i++)
      if (this[i] == object) return i;
    return -1;
  },

  reverse: function(inline) {
    return (inline !== false ? this : this.toArray())._reverse();
  },

  reduce: function() {
    return this.length > 1 ? this : this[0];
  },

  uniq: function() {
    return this.inject([], function(array, value) {
      return array.include(value) ? array : array.concat([value]);
    });
  },

  clone: function() {
    return [].concat(this);
  },

  size: function() {
    return this.length;
  },

  inspect: function() {
    return '[' + this.map(Object.inspect).join(', ') + ']';
  }
});

Array.prototype.toArray = Array.prototype.clone;

function $w(string){
  string = string.strip();
  return string ? string.split(/\s+/) : [];
}

if(window.opera){
  Array.prototype.concat = function(){
    var array = [];
    for(var i = 0, length = this.length; i < length; i++) array.push(this[i]);
    for(var i = 0, length = arguments.length; i < length; i++) {
      if(arguments[i].constructor == Array) {
        for(var j = 0, arrayLength = arguments[i].length; j < arrayLength; j++)
          array.push(arguments[i][j]);
      } else {
        array.push(arguments[i]);
      }
    }
    return array;
  }
}
var Hash = function(obj) {
  Object.extend(this, obj || {});
};

Object.extend(Hash, {
  toQueryString: function(obj) {
    var parts = [];

	  this.prototype._each.call(obj, function(pair) {
      if (!pair.key) return;

      if (pair.value && pair.value.constructor == Array) {
        var values = pair.value.compact();
        if (values.length < 2) pair.value = values.reduce();
        else {
        	key = encodeURIComponent(pair.key);
          values.each(function(value) {
            value = value != undefined ? encodeURIComponent(value) : '';
            parts.push(key + '=' + encodeURIComponent(value));
          });
          return;
        }
      }
      if (pair.value == undefined) pair[1] = '';
      parts.push(pair.map(encodeURIComponent).join('='));
	  });

    return parts.join('&');
  }
});

Object.extend(Hash.prototype, Enumerable);
Object.extend(Hash.prototype, {
  _each: function(iterator) {
    for (var key in this) {
      var value = this[key];
      if (value && value == Hash.prototype[key]) continue;

      var pair = [key, value];
      pair.key = key;
      pair.value = value;
      iterator(pair);
    }
  },

  keys: function() {
    return this.pluck('key');
  },

  values: function() {
    return this.pluck('value');
  },

  merge: function(hash) {
    return $H(hash).inject(this, function(mergedHash, pair) {
      mergedHash[pair.key] = pair.value;
      return mergedHash;
    });
  },

  remove: function() {
    var result;
    for(var i = 0, length = arguments.length; i < length; i++) {
      var value = this[arguments[i]];
      if (value !== undefined){
        if (result === undefined) result = value;
        else {
          if (result.constructor != Array) result = [result];
          result.push(value)
        }
      }
      delete this[arguments[i]];
    }
    return result;
  },

  toQueryString: function() {
    return Hash.toQueryString(this);
  },

  inspect: function() {
    return '#<Hash:{' + this.map(function(pair) {
      return pair.map(Object.inspect).join(': ');
    }).join(', ') + '}>';
  }
});

function $H(object) {
  if (object && object.constructor == Hash) return object;
  return new Hash(object);
};
ObjectRange = Class.create();
Object.extend(ObjectRange.prototype, Enumerable);
Object.extend(ObjectRange.prototype, {
  initialize: function(start, end, exclusive) {
    this.start = start;
    this.end = end;
    this.exclusive = exclusive;
  },

  _each: function(iterator) {
    var value = this.start;
    while (this.include(value)) {
      iterator(value);
      value = value.succ();
    }
  },

  include: function(value) {
    if (value < this.start)
      return false;
    if (this.exclusive)
      return value < this.end;
    return value <= this.end;
  }
});

var $R = function(start, end, exclusive) {
  return new ObjectRange(start, end, exclusive);
}

var Ajax = {
  getTransport: function() {
    return Try.these(
      function() {return new XMLHttpRequest()},
      function() {return new ActiveXObject('Msxml2.XMLHTTP')},
      function() {return new ActiveXObject('Microsoft.XMLHTTP')}
    ) || false;
  },

  activeRequestCount: 0
}

Ajax.Responders = {
  responders: [],

  _each: function(iterator) {
    this.responders._each(iterator);
  },

  register: function(responder) {
    if (!this.include(responder))
      this.responders.push(responder);
  },

  unregister: function(responder) {
    this.responders = this.responders.without(responder);
  },

  dispatch: function(callback, request, transport, json) {
    this.each(function(responder) {
      if (typeof responder[callback] == 'function') {
        try {
          responder[callback].apply(responder, [request, transport, json]);
        } catch (e) {}
      }
    });
  }
};

Object.extend(Ajax.Responders, Enumerable);

Ajax.Responders.register({
  onCreate: function() {
    Ajax.activeRequestCount++;
  },
  onComplete: function() {
    Ajax.activeRequestCount--;
  }
});

Ajax.Base = function() {};
Ajax.Base.prototype = {
  setOptions: function(options) {
    this.options = {
      method:       'post',
      asynchronous: true,
      contentType:  'application/x-www-form-urlencoded',
      encoding:     'UTF-8',
      parameters:   ''
    }
    Object.extend(this.options, options || {});

    this.options.method = this.options.method.toLowerCase();
    if (typeof this.options.parameters == 'string')
      this.options.parameters = this.options.parameters.toQueryParams();
  }
}

Ajax.Request = Class.create();
Ajax.Request.Events =
  ['Uninitialized', 'Loading', 'Loaded', 'Interactive', 'Complete'];

Ajax.Request.prototype = Object.extend(new Ajax.Base(), {
  _complete: false,

  initialize: function(url, options) {
    this.transport = Ajax.getTransport();
    this.setOptions(options);
    this.request(url);
  },

  request: function(url) {
    this.url = url;
    this.method = this.options.method;
    var params = this.options.parameters;

    if (!['get', 'post'].include(this.method)) {
      // simulate other verbs over post
      params['_method'] = this.method;
      this.method = 'post';
    }

    params = Hash.toQueryString(params);
    if (params && /Konqueror|Safari|KHTML/.test(navigator.userAgent)) params += '&_='

    // when GET, append parameters to URL
    if (this.method == 'get' && params)
      this.url += (this.url.indexOf('?') > -1 ? '&' : '?') + params;

    try {
      Ajax.Responders.dispatch('onCreate', this, this.transport);

      this.transport.open(this.method.toUpperCase(), this.url,
        this.options.asynchronous);

      if (this.options.asynchronous)
        setTimeout(function() { this.respondToReadyState(1) }.bind(this), 10);

      this.transport.onreadystatechange = this.onStateChange.bind(this);
      this.setRequestHeaders();

      var body = this.method == 'post' ? (this.options.postBody || params) : null;

      this.transport.send(body);

      /* Force Firefox to handle ready state 4 for synchronous requests */
      if (!this.options.asynchronous && this.transport.overrideMimeType)
        this.onStateChange();

    }
    catch (e) {
      this.dispatchException(e);
    }
  },

  onStateChange: function() {
    var readyState = this.transport.readyState;
    if (readyState > 1 && !((readyState == 4) && this._complete))
      this.respondToReadyState(this.transport.readyState);
  },

  setRequestHeaders: function() {
    var headers = {
      'X-Requested-With': 'XMLHttpRequest',
      'X-Prototype-Version': Prototype.Version,
      'Accept': 'text/javascript, text/html, application/xml, text/xml, */*'
    };

    if (this.method == 'post') {
      headers['Content-type'] = this.options.contentType +
        (this.options.encoding ? '; charset=' + this.options.encoding : '');

      /* Force "Connection: close" for older Mozilla browsers to work
       * around a bug where XMLHttpRequest sends an incorrect
       * Content-length header. See Mozilla Bugzilla #246651.
       */
      if (this.transport.overrideMimeType &&
          (navigator.userAgent.match(/Gecko\/(\d{4})/) || [0,2005])[1] < 2005)
            headers['Connection'] = 'close';
    }

    // user-defined headers
    if (typeof this.options.requestHeaders == 'object') {
      var extras = this.options.requestHeaders;

      if (typeof extras.push == 'function')
        for (var i = 0, length = extras.length; i < length; i += 2)
          headers[extras[i]] = extras[i+1];
      else
        $H(extras).each(function(pair) { headers[pair.key] = pair.value });
    }

    for (var name in headers)
      this.transport.setRequestHeader(name, headers[name]);
  },

  success: function() {
    return !this.transport.status
        || (this.transport.status >= 200 && this.transport.status < 300);
  },

  respondToReadyState: function(readyState) {
    var state = Ajax.Request.Events[readyState];
    var transport = this.transport, json = this.evalJSON();

    if (state == 'Complete') {
      try {
        this._complete = true;
        (this.options['on' + this.transport.status]
         || this.options['on' + (this.success() ? 'Success' : 'Failure')]
         || Prototype.emptyFunction)(transport, json);
      } catch (e) {
        this.dispatchException(e);
      }

      if ((this.getHeader('Content-type') || 'text/javascript').strip().
        match(/^(text|application)\/(x-)?(java|ecma)script(;.*)?$/i))
          this.evalResponse();
    }

    try {
      (this.options['on' + state] || Prototype.emptyFunction)(transport, json);
      Ajax.Responders.dispatch('on' + state, this, transport, json);
    } catch (e) {
      this.dispatchException(e);
    }

    if (state == 'Complete') {
      // avoid memory leak in MSIE: clean up
      this.transport.onreadystatechange = Prototype.emptyFunction;
    }
  },

  getHeader: function(name) {
    try {
      return this.transport.getResponseHeader(name);
    } catch (e) { return null }
  },

  evalJSON: function() {
    try {
      var json = this.getHeader('X-JSON');
      return json ? eval('(' + json + ')') : null;
    } catch (e) { return null }
  },

  evalResponse: function() {
    try {
      return eval(this.transport.responseText);
    } catch (e) {
      this.dispatchException(e);
    }
  },

  dispatchException: function(exception) {
    (this.options.onException || Prototype.emptyFunction)(this, exception);
    Ajax.Responders.dispatch('onException', this, exception);
  }
});

Ajax.Updater = Class.create();

Object.extend(Object.extend(Ajax.Updater.prototype, Ajax.Request.prototype), {
  initialize: function(container, url, options) {
    this.container = {
      success: (container.success || container),
      failure: (container.failure || (container.success ? null : container))
    }

    this.transport = Ajax.getTransport();
    this.setOptions(options);

    var onComplete = this.options.onComplete || Prototype.emptyFunction;
    this.options.onComplete = (function(transport, param) {
      this.updateContent();
      onComplete(transport, param);
    }).bind(this);

    this.request(url);
  },

  updateContent: function() {
    var receiver = this.container[this.success() ? 'success' : 'failure'];
    var response = this.transport.responseText;

    if (!this.options.evalScripts) response = response.stripScripts();

    if (receiver = $(receiver)) {
      if (this.options.insertion)
        new this.options.insertion(receiver, response);
      else
        receiver.update(response);
    }

    if (this.success()) {
      if (this.onComplete)
        setTimeout(this.onComplete.bind(this), 10);
    }
  }
});

Ajax.PeriodicalUpdater = Class.create();
Ajax.PeriodicalUpdater.prototype = Object.extend(new Ajax.Base(), {
  initialize: function(container, url, options) {
    this.setOptions(options);
    this.onComplete = this.options.onComplete;

    this.frequency = (this.options.frequency || 2);
    this.decay = (this.options.decay || 1);

    this.updater = {};
    this.container = container;
    this.url = url;

    this.start();
  },

  start: function() {
    this.options.onComplete = this.updateComplete.bind(this);
    this.onTimerEvent();
  },

  stop: function() {
    this.updater.options.onComplete = undefined;
    clearTimeout(this.timer);
    (this.onComplete || Prototype.emptyFunction).apply(this, arguments);
  },

  updateComplete: function(request) {
    if (this.options.decay) {
      this.decay = (request.responseText == this.lastText ?
        this.decay * this.options.decay : 1);

      this.lastText = request.responseText;
    }
    this.timer = setTimeout(this.onTimerEvent.bind(this),
      this.decay * this.frequency * 1000);
  },

  onTimerEvent: function() {
    this.updater = new Ajax.Updater(this.container, this.url, this.options);
  }
});
function $(element) {
  if (arguments.length > 1) {
    for (var i = 0, elements = [], length = arguments.length; i < length; i++)
      elements.push($(arguments[i]));
    return elements;
  }
  if (typeof element == 'string')
    element = document.getElementById(element);
  return Element.extend(element);
}

if (Prototype.BrowserFeatures.XPath) {
  document._getElementsByXPath = function(expression, parentElement) {
    var results = [];
    var query = document.evaluate(expression, $(parentElement) || document,
      null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);
    for (var i = 0, length = query.snapshotLength; i < length; i++)
      results.push(query.snapshotItem(i));
    return results;
  };
}

document.getElementsByClassName = function(className, parentElement) {
  if (Prototype.BrowserFeatures.XPath) {
    var q = ".//*[contains(concat(' ', @class, ' '), ' " + className + " ')]";
    return document._getElementsByXPath(q, parentElement);
  } else {
    var children = ($(parentElement) || document.body).getElementsByTagName('*');
    var elements = [], child;
    for (var i = 0, length = children.length; i < length; i++) {
      child = children[i];
      if (Element.hasClassName(child, className))
        elements.push(Element.extend(child));
    }
    return elements;
  }
};

/*--------------------------------------------------------------------------*/

if (!window.Element)
  var Element = new Object();

Element.extend = function(element) {
  if (!element || _nativeExtensions || element.nodeType == 3) return element;

  try {
  if (!element._extended && element.tagName && element != window) {
    var methods = Object.clone(Element.Methods), cache = Element.extend.cache;

    if (element.tagName == 'FORM')
      Object.extend(methods, Form.Methods);
    if (['INPUT', 'TEXTAREA', 'SELECT'].include(element.tagName))
      Object.extend(methods, Form.Element.Methods);

    Object.extend(methods, Element.Methods.Simulated);

    for (var property in methods) {
      var value = methods[property];
      if (typeof value == 'function' && !(property in element))
        element[property] = cache.findOrStore(value);
    }
  }

  element._extended = true;
  } catch(e) {}
  return element;
};

Element.extend.cache = {
  findOrStore: function(value) {
    return this[value] = this[value] || function() {
      return value.apply(null, [this].concat($A(arguments)));
    }
  }
};

Element.Methods = {
  visible: function(element) {
    return $(element).style.display != 'none';
  },

  toggle: function(element) {
    element = $(element);
    Element[Element.visible(element) ? 'hide' : 'show'](element);
    return element;
  },

  hide: function(element) {
    $(element).style.display = 'none';
    return element;
  },

  show: function(element) {
    $(element).style.display = '';
    return element;
  },

  remove: function(element) {
    element = $(element);
    element.parentNode.removeChild(element);
    return element;
  },

  update: function(element, html) {
    html = typeof html == 'undefined' ? '' : html.toString();
    $(element).innerHTML = html.stripScripts();
    setTimeout(function() {html.evalScripts()}, 10);
    return element;
  },

  replace: function(element, html) {
    element = $(element);
    html = typeof html == 'undefined' ? '' : html.toString();
    if (element.outerHTML) {
      element.outerHTML = html.stripScripts();
    } else {
      var range = element.ownerDocument.createRange();
      range.selectNodeContents(element);
      element.parentNode.replaceChild(
        range.createContextualFragment(html.stripScripts()), element);
    }
    setTimeout(function() {html.evalScripts()}, 10);
    return element;
  },

  inspect: function(element) {
    element = $(element);
    var result = '<' + element.tagName.toLowerCase();
    $H({'id': 'id', 'className': 'class'}).each(function(pair) {
      var property = pair.first(), attribute = pair.last();
      var value = (element[property] || '').toString();
      if (value) result += ' ' + attribute + '=' + value.inspect(true);
    });
    return result + '>';
  },

  recursivelyCollect: function(element, property) {
    element = $(element);
    var elements = [];
    while (element = element[property])
      if (element.nodeType == 1)
        elements.push(Element.extend(element));
    return elements;
  },

  ancestors: function(element) {
    return $(element).recursivelyCollect('parentNode');
  },

  descendants: function(element) {
    return $A($(element).getElementsByTagName('*'));
  },

  immediateDescendants: function(element) {
    if (!(element = $(element).firstChild)) return [];
    while (element && element.nodeType != 1) element = element.nextSibling;
    if (element) return [element].concat($(element).nextSiblings());
    return [];
  },

  previousSiblings: function(element) {
    return $(element).recursivelyCollect('previousSibling');
  },

  nextSiblings: function(element) {
    return $(element).recursivelyCollect('nextSibling');
  },

  siblings: function(element) {
    element = $(element);
    return element.previousSiblings().reverse().concat(element.nextSiblings());
  },

  match: function(element, selector) {
    if (typeof selector == 'string')
      selector = new Selector(selector);
    return selector.match($(element));
  },

  up: function(element, expression, index) {
    return Selector.findElement($(element).ancestors(), expression, index);
  },

  down: function(element, expression, index) {
    return Selector.findElement($(element).descendants(), expression, index);
  },

  previous: function(element, expression, index) {
    return Selector.findElement($(element).previousSiblings(), expression, index);
  },

  next: function(element, expression, index) {
    return Selector.findElement($(element).nextSiblings(), expression, index);
  },

  getElementsBySelector: function() {
    var args = $A(arguments), element = $(args.shift());
    return Selector.findChildElements(element, args);
  },

  getElementsByClassName: function(element, className) {
    return document.getElementsByClassName(className, element);
  },

  readAttribute: function(element, name) {
    element = $(element);
    if (document.all && !window.opera) {
      var t = Element._attributeTranslations;
      if (t.values[name]) return t.values[name](element, name);
      if (t.names[name])  name = t.names[name];
      var attribute = element.attributes[name];
      if(attribute) return attribute.nodeValue;
    }
    return element.getAttribute(name);
  },

  getHeight: function(element) {
    return $(element).getDimensions().height;
  },

  getWidth: function(element) {
    return $(element).getDimensions().width;
  },

  classNames: function(element) {
    return new Element.ClassNames(element);
  },

  hasClassName: function(element, className) {
    if (!(element = $(element))) return;
    var elementClassName = element.className;
    if (elementClassName.length == 0) return false;
    if (elementClassName == className ||
        elementClassName.match(new RegExp("(^|\\s)" + className + "(\\s|$)")))
      return true;
    return false;
  },

  addClassName: function(element, className) {
    if (!(element = $(element))) return;
    Element.classNames(element).add(className);
    return element;
  },

  removeClassName: function(element, className) {
    if (!(element = $(element))) return;
    Element.classNames(element).remove(className);
    return element;
  },

  toggleClassName: function(element, className) {
    if (!(element = $(element))) return;
    Element.classNames(element)[element.hasClassName(className) ? 'remove' : 'add'](className);
    return element;
  },

  observe: function() {
    Event.observe.apply(Event, arguments);
    return $A(arguments).first();
  },

  stopObserving: function() {
    Event.stopObserving.apply(Event, arguments);
    return $A(arguments).first();
  },

  // removes whitespace-only text node children
  cleanWhitespace: function(element) {
    element = $(element);
    var node = element.firstChild;
    while (node) {
      var nextNode = node.nextSibling;
      if (node.nodeType == 3 && !/\S/.test(node.nodeValue))
        element.removeChild(node);
      node = nextNode;
    }
    return element;
  },

  empty: function(element) {
    return $(element).innerHTML.match(/^\s*$/);
  },

  descendantOf: function(element, ancestor) {
    element = $(element), ancestor = $(ancestor);
    while (element = element.parentNode)
      if (element == ancestor) return true;
    return false;
  },

  scrollTo: function(element) {
    element = $(element);
    var pos = Position.cumulativeOffset(element);
    window.scrollTo(pos[0], pos[1]);
    return element;
  },

  getStyle: function(element, style) {
    element = $(element);
    if (['float','cssFloat'].include(style))
      style = (typeof element.style.styleFloat != 'undefined' ? 'styleFloat' : 'cssFloat');
    style = style.camelize();
    var value = element.style[style];
    if (!value) {
      if (document.defaultView && document.defaultView.getComputedStyle) {
        var css = document.defaultView.getComputedStyle(element, null);
        value = css ? css[style] : null;
      } else if (element.currentStyle) {
        value = element.currentStyle[style];
      }
    }

    if((value == 'auto') && ['width','height'].include(style) && (element.getStyle('display') != 'none'))
      value = element['offset'+style.capitalize()] + 'px';

    if (window.opera && ['left', 'top', 'right', 'bottom'].include(style))
      if (Element.getStyle(element, 'position') == 'static') value = 'auto';
    if(style == 'opacity') {
      if(value) return parseFloat(value);
      if(value = (element.getStyle('filter') || '').match(/alpha\(opacity=(.*)\)/))
        if(value[1]) return parseFloat(value[1]) / 100;
      return 1.0;
    }
    return value == 'auto' ? null : value;
  },

  setStyle: function(element, style) {
    element = $(element);
    for (var name in style) {
      var value = style[name];
      if(name == 'opacity') {
        if (value == 1) {
          value = (/Gecko/.test(navigator.userAgent) &&
            !/Konqueror|Safari|KHTML/.test(navigator.userAgent)) ? 0.999999 : 1.0;
          if(/MSIE/.test(navigator.userAgent) && !window.opera)
            element.style.filter = element.getStyle('filter').replace(/alpha\([^\)]*\)/gi,'');
        } else if(value === '') {
          if(/MSIE/.test(navigator.userAgent) && !window.opera)
            element.style.filter = element.getStyle('filter').replace(/alpha\([^\)]*\)/gi,'');
        } else {
          if(value < 0.00001) value = 0;
          if(/MSIE/.test(navigator.userAgent) && !window.opera)
            element.style.filter = element.getStyle('filter').replace(/alpha\([^\)]*\)/gi,'') +
              'alpha(opacity='+value*100+')';
        }
      } else if(['float','cssFloat'].include(name)) name = (typeof element.style.styleFloat != 'undefined') ? 'styleFloat' : 'cssFloat';
      element.style[name.camelize()] = value;
    }
    return element;
  },

  getDimensions: function(element) {
    element = $(element);
    var display = $(element).getStyle('display');
    if (display != 'none' && display != null) // Safari bug
      return {width: element.offsetWidth, height: element.offsetHeight};

    // All *Width and *Height properties give 0 on elements with display none,
    // so enable the element temporarily
    var els = element.style;
    var originalVisibility = els.visibility;
    var originalPosition = els.position;
    var originalDisplay = els.display;
    els.visibility = 'hidden';
    els.position = 'absolute';
    els.display = 'block';
    var originalWidth = element.clientWidth;
    var originalHeight = element.clientHeight;
    els.display = originalDisplay;
    els.position = originalPosition;
    els.visibility = originalVisibility;
    return {width: originalWidth, height: originalHeight};
  },

  makePositioned: function(element) {
    element = $(element);
    var pos = Element.getStyle(element, 'position');
    if (pos == 'static' || !pos) {
      element._madePositioned = true;
      element.style.position = 'relative';
      // Opera returns the offset relative to the positioning context, when an
      // element is position relative but top and left have not been defined
      if (window.opera) {
        element.style.top = 0;
        element.style.left = 0;
      }
    }
    return element;
  },

  undoPositioned: function(element) {
    element = $(element);
    if (element._madePositioned) {
      element._madePositioned = undefined;
      element.style.position =
        element.style.top =
        element.style.left =
        element.style.bottom =
        element.style.right = '';
    }
    return element;
  },

  makeClipping: function(element) {
    element = $(element);
    if (element._overflow) return element;
    element._overflow = element.style.overflow || 'auto';
    if ((Element.getStyle(element, 'overflow') || 'visible') != 'hidden')
      element.style.overflow = 'hidden';
    return element;
  },

  undoClipping: function(element) {
    element = $(element);
    if (!element._overflow) return element;
    element.style.overflow = element._overflow == 'auto' ? '' : element._overflow;
    element._overflow = null;
    return element;
  }
};

Object.extend(Element.Methods, {childOf: Element.Methods.descendantOf});

Element._attributeTranslations = {};

Element._attributeTranslations.names = {
  colspan:   "colSpan",
  rowspan:   "rowSpan",
  valign:    "vAlign",
  datetime:  "dateTime",
  accesskey: "accessKey",
  tabindex:  "tabIndex",
  enctype:   "encType",
  maxlength: "maxLength",
  readonly:  "readOnly",
  longdesc:  "longDesc"
};

Element._attributeTranslations.values = {
  _getAttr: function(element, attribute) {
    return element.getAttribute(attribute, 2);
  },

  _flag: function(element, attribute) {
    return $(element).hasAttribute(attribute) ? attribute : null;
  },

  style: function(element) {
    return element.style.cssText.toLowerCase();
  },

  title: function(element) {
    var node = element.getAttributeNode('title');
    return node.specified ? node.nodeValue : null;
  }
};

Object.extend(Element._attributeTranslations.values, {
  href: Element._attributeTranslations.values._getAttr,
  src:  Element._attributeTranslations.values._getAttr,
  disabled: Element._attributeTranslations.values._flag,
  checked:  Element._attributeTranslations.values._flag,
  readonly: Element._attributeTranslations.values._flag,
  multiple: Element._attributeTranslations.values._flag
});

Element.Methods.Simulated = {
  hasAttribute: function(element, attribute) {
    var t = Element._attributeTranslations;
    attribute = t.names[attribute] || attribute;
    return $(element).getAttributeNode(attribute).specified;
  }
};

// IE is missing .innerHTML support for TABLE-related elements
if (document.all && !window.opera){
  Element.Methods.update = function(element, html) {
    element = $(element);
    html = typeof html == 'undefined' ? '' : html.toString();
    var tagName = element.tagName.toUpperCase();
    if (['THEAD','TBODY','TR','TD'].include(tagName)) {
      var div = document.createElement('div');
      switch (tagName) {
        case 'THEAD':
        case 'TBODY':
          div.innerHTML = '<table><tbody>' +  html.stripScripts() + '</tbody></table>';
          depth = 2;
          break;
        case 'TR':
          div.innerHTML = '<table><tbody><tr>' +  html.stripScripts() + '</tr></tbody></table>';
          depth = 3;
          break;
        case 'TD':
          div.innerHTML = '<table><tbody><tr><td>' +  html.stripScripts() + '</td></tr></tbody></table>';
          depth = 4;
      }
      $A(element.childNodes).each(function(node){
        element.removeChild(node)
      });
      depth.times(function(){ div = div.firstChild });

      $A(div.childNodes).each(
        function(node){ element.appendChild(node) });
    } else {
      element.innerHTML = html.stripScripts();
    }
    setTimeout(function() {html.evalScripts()}, 10);
    return element;
  }
};

Object.extend(Element, Element.Methods);

var _nativeExtensions = false;

if(/Konqueror|Safari|KHTML/.test(navigator.userAgent))
  ['', 'Form', 'Input', 'TextArea', 'Select'].each(function(tag) {
    var className = 'HTML' + tag + 'Element';
    if(window[className]) return;
    var klass = window[className] = {};
    klass.prototype = document.createElement(tag ? tag.toLowerCase() : 'div').__proto__;
  });

Element.addMethods = function(methods) {
  Object.extend(Element.Methods, methods || {});

  function copy(methods, destination, onlyIfAbsent) {
    onlyIfAbsent = onlyIfAbsent || false;
    var cache = Element.extend.cache;
    for (var property in methods) {
      var value = methods[property];
      if (!onlyIfAbsent || !(property in destination))
        destination[property] = cache.findOrStore(value);
    }
  }

  if (typeof HTMLElement != 'undefined') {
    copy(Element.Methods, HTMLElement.prototype);
    copy(Element.Methods.Simulated, HTMLElement.prototype, true);
    copy(Form.Methods, HTMLFormElement.prototype);
    [HTMLInputElement, HTMLTextAreaElement, HTMLSelectElement].each(function(klass) {
      copy(Form.Element.Methods, klass.prototype);
    });
    _nativeExtensions = true;
  }
}

var Toggle = new Object();
Toggle.display = Element.toggle;

/*--------------------------------------------------------------------------*/

Abstract.Insertion = function(adjacency) {
  this.adjacency = adjacency;
}

Abstract.Insertion.prototype = {
  initialize: function(element, content) {
    this.element = $(element);
    this.content = content.stripScripts();

    if (this.adjacency && this.element != null && this.element.insertAdjacentHTML) {
      try {
        this.element.insertAdjacentHTML(this.adjacency, this.content);
      } catch (e) {
        var tagName = this.element.tagName.toUpperCase();
        if (['TABLE', 'TBODY', 'TR'].include(tagName)) {
          this.insertContent(this.contentFromAnonymousTable());
        } else {
          throw e;
        }
      }
    } else {
      this.range = this.element.ownerDocument.createRange();
      if (this.initializeRange) this.initializeRange();
      this.insertContent([this.range.createContextualFragment(this.content)]);
    }

    setTimeout(function() {content.evalScripts()}, 10);
  },

  contentFromAnonymousTable: function() {
    var div = document.createElement('div');
    div.innerHTML = '<table><tbody>' + this.content + '</tbody></table>';
    return $A(div.childNodes[0].childNodes[0].childNodes);
  }
}

var Insertion = new Object();

Insertion.Before = Class.create();
Insertion.Before.prototype = Object.extend(new Abstract.Insertion('beforeBegin'), {
  initializeRange: function() {
    this.range.setStartBefore(this.element);
  },

  insertContent: function(fragments) {
    fragments.each((function(fragment) {
      this.element.parentNode.insertBefore(fragment, this.element);
    }).bind(this));
  }
});

Insertion.Top = Class.create();
Insertion.Top.prototype = Object.extend(new Abstract.Insertion('afterBegin'), {
  initializeRange: function() {
    this.range.selectNodeContents(this.element);
    this.range.collapse(true);
  },

  insertContent: function(fragments) {
    fragments.reverse(false).each((function(fragment) {
      this.element.insertBefore(fragment, this.element.firstChild);
    }).bind(this));
  }
});

Insertion.Bottom = Class.create();
Insertion.Bottom.prototype = Object.extend(new Abstract.Insertion('beforeEnd'), {
  initializeRange: function() {
    this.range.selectNodeContents(this.element);
    this.range.collapse(this.element);
  },

  insertContent: function(fragments) {
    fragments.each((function(fragment) {
      this.element.appendChild(fragment);
    }).bind(this));
  }
});

Insertion.After = Class.create();
Insertion.After.prototype = Object.extend(new Abstract.Insertion('afterEnd'), {
  initializeRange: function() {
    this.range.setStartAfter(this.element);
  },

  insertContent: function(fragments) {
    fragments.each((function(fragment) {
      this.element.parentNode.insertBefore(fragment,
        this.element.nextSibling);
    }).bind(this));
  }
});

/*--------------------------------------------------------------------------*/

Element.ClassNames = Class.create();
Element.ClassNames.prototype = {
  initialize: function(element) {
    this.element = $(element);
  },

  _each: function(iterator) {
    this.element.className.split(/\s+/).select(function(name) {
      return name.length > 0;
    })._each(iterator);
  },

  set: function(className) {
    this.element.className = className;
  },

  add: function(classNameToAdd) {
    if (this.include(classNameToAdd)) return;
    this.set($A(this).concat(classNameToAdd).join(' '));
  },

  remove: function(classNameToRemove) {
    if (!this.include(classNameToRemove)) return;
    this.set($A(this).without(classNameToRemove).join(' '));
  },

  toString: function() {
    return $A(this).join(' ');
  }
};

Object.extend(Element.ClassNames.prototype, Enumerable);
var Selector = Class.create();
Selector.prototype = {
  initialize: function(expression) {
    this.params = {classNames: []};
    this.expression = expression.toString().strip();
    this.parseExpression();
    this.compileMatcher();
  },

  parseExpression: function() {
    function abort(message) { throw 'Parse error in selector: ' + message; }

    if (this.expression == '')  abort('empty expression');

    var params = this.params, expr = this.expression, match, modifier, clause, rest;
    while (match = expr.match(/^(.*)\[([a-z0-9_:-]+?)(?:([~\|!]?=)(?:"([^"]*)"|([^\]\s]*)))?\]$/i)) {
      params.attributes = params.attributes || [];
      params.attributes.push({name: match[2], operator: match[3], value: match[4] || match[5] || ''});
      expr = match[1];
    }

    if (expr == '*') return this.params.wildcard = true;

    while (match = expr.match(/^([^a-z0-9_-])?([a-z0-9_-]+)(.*)/i)) {
      modifier = match[1], clause = match[2], rest = match[3];
      switch (modifier) {
        case '#':       params.id = clause; break;
        case '.':       params.classNames.push(clause); break;
        case '':
        case undefined: params.tagName = clause.toUpperCase(); break;
        default:        abort(expr.inspect());
      }
      expr = rest;
    }

    if (expr.length > 0) abort(expr.inspect());
  },

  buildMatchExpression: function() {
    var params = this.params, conditions = [], clause;

    if (params.wildcard)
      conditions.push('true');
    if (clause = params.id)
      conditions.push('element.readAttribute("id") == ' + clause.inspect());
    if (clause = params.tagName)
      conditions.push('element.tagName.toUpperCase() == ' + clause.inspect());
    if ((clause = params.classNames).length > 0)
      for (var i = 0, length = clause.length; i < length; i++)
        conditions.push('element.hasClassName(' + clause[i].inspect() + ')');
    if (clause = params.attributes) {
      clause.each(function(attribute) {
        var value = 'element.readAttribute(' + attribute.name.inspect() + ')';
        var splitValueBy = function(delimiter) {
          return value + ' && ' + value + '.split(' + delimiter.inspect() + ')';
        }

        switch (attribute.operator) {
          case '=':       conditions.push(value + ' == ' + attribute.value.inspect()); break;
          case '~=':      conditions.push(splitValueBy(' ') + '.include(' + attribute.value.inspect() + ')'); break;
          case '|=':      conditions.push(
                            splitValueBy('-') + '.first().toUpperCase() == ' + attribute.value.toUpperCase().inspect()
                          ); break;
          case '!=':      conditions.push(value + ' != ' + attribute.value.inspect()); break;
          case '':
          case undefined: conditions.push('element.hasAttribute(' + attribute.name.inspect() + ')'); break;
          default:        throw 'Unknown operator ' + attribute.operator + ' in selector';
        }
      });
    }

    return conditions.join(' && ');
  },

  compileMatcher: function() {
    this.match = new Function('element', 'if (!element.tagName) return false; \
      element = $(element); \
      return ' + this.buildMatchExpression());
  },

  findElements: function(scope) {
    var element;

    if (element = $(this.params.id))
      if (this.match(element))
        if (!scope || Element.childOf(element, scope))
          return [element];

    scope = (scope || document).getElementsByTagName(this.params.tagName || '*');

    var results = [];
    for (var i = 0, length = scope.length; i < length; i++)
      if (this.match(element = scope[i]))
        results.push(Element.extend(element));

    return results;
  },

  toString: function() {
    return this.expression;
  }
}

Object.extend(Selector, {
  matchElements: function(elements, expression) {
    var selector = new Selector(expression);
    return elements.select(selector.match.bind(selector)).map(Element.extend);
  },

  findElement: function(elements, expression, index) {
    if (typeof expression == 'number') index = expression, expression = false;
    return Selector.matchElements(elements, expression || '*')[index || 0];
  },

  findChildElements: function(element, expressions) {
    return expressions.map(function(expression) {
      return expression.match(/[^\s"]+(?:"[^"]*"[^\s"]+)*/g).inject([null], function(results, expr) {
        var selector = new Selector(expr);
        return results.inject([], function(elements, result) {
          return elements.concat(selector.findElements(result || element));
        });
      });
    }).flatten();
  }
});

function $$() {
  return Selector.findChildElements(document, $A(arguments));
}
var Form = {
  reset: function(form) {
    $(form).reset();
    return form;
  },

  serializeElements: function(elements, getHash) {
    var data = elements.inject({}, function(result, element) {
      if (!element.disabled && element.name) {
        var key = element.name, value = $(element).getValue();
        if (value != undefined) {
          if (result[key]) {
            if (result[key].constructor != Array) result[key] = [result[key]];
            result[key].push(value);
          }
          else result[key] = value;
        }
      }
      return result;
    });

    return getHash ? data : Hash.toQueryString(data);
  }
};

Form.Methods = {
  serialize: function(form, getHash) {
    return Form.serializeElements(Form.getElements(form), getHash);
  },

  getElements: function(form) {
    return $A($(form).getElementsByTagName('*')).inject([],
      function(elements, child) {
        if (Form.Element.Serializers[child.tagName.toLowerCase()])
          elements.push(Element.extend(child));
        return elements;
      }
    );
  },

  getInputs: function(form, typeName, name) {
    form = $(form);
    var inputs = form.getElementsByTagName('input');

    if (!typeName && !name) return $A(inputs).map(Element.extend);

    for (var i = 0, matchingInputs = [], length = inputs.length; i < length; i++) {
      var input = inputs[i];
      if ((typeName && input.type != typeName) || (name && input.name != name))
        continue;
      matchingInputs.push(Element.extend(input));
    }

    return matchingInputs;
  },

  disable: function(form) {
    form = $(form);
    form.getElements().each(function(element) {
      element.blur();
      element.disabled = 'true';
    });
    return form;
  },

  enable: function(form) {
    form = $(form);
    form.getElements().each(function(element) {
      element.disabled = '';
    });
    return form;
  },

  findFirstElement: function(form) {
    return $(form).getElements().find(function(element) {
      return element.type != 'hidden' && !element.disabled &&
        ['input', 'select', 'textarea'].include(element.tagName.toLowerCase());
    });
  },

  focusFirstElement: function(form) {
    form = $(form);
    form.findFirstElement().activate();
    return form;
  }
}

Object.extend(Form, Form.Methods);

/*--------------------------------------------------------------------------*/

Form.Element = {
  focus: function(element) {
    $(element).focus();
    return element;
  },

  select: function(element) {
    $(element).select();
    return element;
  }
}

Form.Element.Methods = {
  serialize: function(element) {
    element = $(element);
    if (!element.disabled && element.name) {
      var value = element.getValue();
      if (value != undefined) {
        var pair = {};
        pair[element.name] = value;
        return Hash.toQueryString(pair);
      }
    }
    return '';
  },

  getValue: function(element) {
    element = $(element);
    var method = element.tagName.toLowerCase();
    return Form.Element.Serializers[method](element);
  },

  clear: function(element) {
    $(element).value = '';
    return element;
  },

  present: function(element) {
    return $(element).value != '';
  },

  activate: function(element) {
    element = $(element);
    element.focus();
    if (element.select && ( element.tagName.toLowerCase() != 'input' ||
      !['button', 'reset', 'submit'].include(element.type) ) )
      element.select();
    return element;
  },

  disable: function(element) {
    element = $(element);
    element.disabled = true;
    return element;
  },

  enable: function(element) {
    element = $(element);
    element.blur();
    element.disabled = false;
    return element;
  }
}

Object.extend(Form.Element, Form.Element.Methods);
var Field = Form.Element;
var $F = Form.Element.getValue;

/*--------------------------------------------------------------------------*/

Form.Element.Serializers = {
  input: function(element) {
    switch (element.type.toLowerCase()) {
      case 'checkbox':
      case 'radio':
        return Form.Element.Serializers.inputSelector(element);
      default:
        return Form.Element.Serializers.textarea(element);
    }
  },

  inputSelector: function(element) {
    return element.checked ? element.value : null;
  },

  textarea: function(element) {
    return element.value;
  },

  select: function(element) {
    return this[element.type == 'select-one' ?
      'selectOne' : 'selectMany'](element);
  },

  selectOne: function(element) {
    var index = element.selectedIndex;
    return index >= 0 ? this.optionValue(element.options[index]) : null;
  },

  selectMany: function(element) {
    var values, length = element.length;
    if (!length) return null;

    for (var i = 0, values = []; i < length; i++) {
      var opt = element.options[i];
      if (opt.selected) values.push(this.optionValue(opt));
    }
    return values;
  },

  optionValue: function(opt) {
    // extend element because hasAttribute may not be native
    return Element.extend(opt).hasAttribute('value') ? opt.value : opt.text;
  }
}

/*--------------------------------------------------------------------------*/

Abstract.TimedObserver = function() {}
Abstract.TimedObserver.prototype = {
  initialize: function(element, frequency, callback) {
    this.frequency = frequency;
    this.element   = $(element);
    this.callback  = callback;

    this.lastValue = this.getValue();
    this.registerCallback();
  },

  registerCallback: function() {
    setInterval(this.onTimerEvent.bind(this), this.frequency * 1000);
  },

  onTimerEvent: function() {
    var value = this.getValue();
    var changed = ('string' == typeof this.lastValue && 'string' == typeof value
      ? this.lastValue != value : String(this.lastValue) != String(value));
    if (changed) {
      this.callback(this.element, value);
      this.lastValue = value;
    }
  }
}

Form.Element.Observer = Class.create();
Form.Element.Observer.prototype = Object.extend(new Abstract.TimedObserver(), {
  getValue: function() {
    return Form.Element.getValue(this.element);
  }
});

Form.Observer = Class.create();
Form.Observer.prototype = Object.extend(new Abstract.TimedObserver(), {
  getValue: function() {
    return Form.serialize(this.element);
  }
});

/*--------------------------------------------------------------------------*/

Abstract.EventObserver = function() {}
Abstract.EventObserver.prototype = {
  initialize: function(element, callback) {
    this.element  = $(element);
    this.callback = callback;

    this.lastValue = this.getValue();
    if (this.element.tagName.toLowerCase() == 'form')
      this.registerFormCallbacks();
    else
      this.registerCallback(this.element);
  },

  onElementEvent: function() {
    var value = this.getValue();
    if (this.lastValue != value) {
      this.callback(this.element, value);
      this.lastValue = value;
    }
  },

  registerFormCallbacks: function() {
    Form.getElements(this.element).each(this.registerCallback.bind(this));
  },

  registerCallback: function(element) {
    if (element.type) {
      switch (element.type.toLowerCase()) {
        case 'checkbox':
        case 'radio':
          Event.observe(element, 'click', this.onElementEvent.bind(this));
          break;
        default:
          Event.observe(element, 'change', this.onElementEvent.bind(this));
          break;
      }
    }
  }
}

Form.Element.EventObserver = Class.create();
Form.Element.EventObserver.prototype = Object.extend(new Abstract.EventObserver(), {
  getValue: function() {
    return Form.Element.getValue(this.element);
  }
});

Form.EventObserver = Class.create();
Form.EventObserver.prototype = Object.extend(new Abstract.EventObserver(), {
  getValue: function() {
    return Form.serialize(this.element);
  }
});
if (!window.Event) {
  var Event = new Object();
}

Object.extend(Event, {
  KEY_BACKSPACE: 8,
  KEY_TAB:       9,
  KEY_RETURN:   13,
  KEY_ESC:      27,
  KEY_LEFT:     37,
  KEY_UP:       38,
  KEY_RIGHT:    39,
  KEY_DOWN:     40,
  KEY_DELETE:   46,
  KEY_HOME:     36,
  KEY_END:      35,
  KEY_PAGEUP:   33,
  KEY_PAGEDOWN: 34,

  element: function(event) {
    return event.target || event.srcElement;
  },

  isLeftClick: function(event) {
    return (((event.which) && (event.which == 1)) ||
            ((event.button) && (event.button == 1)));
  },

  pointerX: function(event) {
    return event.pageX || (event.clientX +
      (document.documentElement.scrollLeft || document.body.scrollLeft));
  },

  pointerY: function(event) {
    return event.pageY || (event.clientY +
      (document.documentElement.scrollTop || document.body.scrollTop));
  },

  stop: function(event) {
    if (event.preventDefault) {
      event.preventDefault();
      event.stopPropagation();
    } else {
      event.returnValue = false;
      event.cancelBubble = true;
    }
  },

  // find the first node with the given tagName, starting from the
  // node the event was triggered on; traverses the DOM upwards
  findElement: function(event, tagName) {
    var element = Event.element(event);
    while (element.parentNode && (!element.tagName ||
        (element.tagName.toUpperCase() != tagName.toUpperCase())))
      element = element.parentNode;
    return element;
  },

  observers: false,

  _observeAndCache: function(element, name, observer, useCapture) {
    if (!this.observers) this.observers = [];
    if (element.addEventListener) {
      this.observers.push([element, name, observer, useCapture]);
      element.addEventListener(name, observer, useCapture);
    } else if (element.attachEvent) {
      this.observers.push([element, name, observer, useCapture]);
      element.attachEvent('on' + name, observer);
    }
  },

  unloadCache: function() {
    if (!Event.observers) return;
    for (var i = 0, length = Event.observers.length; i < length; i++) {
      Event.stopObserving.apply(this, Event.observers[i]);
      Event.observers[i][0] = null;
    }
    Event.observers = false;
  },

  observe: function(element, name, observer, useCapture) {
    element = $(element);
    useCapture = useCapture || false;

    if (name == 'keypress' &&
        (navigator.appVersion.match(/Konqueror|Safari|KHTML/)
        || element.attachEvent))
      name = 'keydown';

    Event._observeAndCache(element, name, observer, useCapture);
  },

  stopObserving: function(element, name, observer, useCapture) {
    element = $(element);
    useCapture = useCapture || false;

    if (name == 'keypress' &&
        (navigator.appVersion.match(/Konqueror|Safari|KHTML/)
        || element.detachEvent))
      name = 'keydown';

    if (element.removeEventListener) {
      element.removeEventListener(name, observer, useCapture);
    } else if (element.detachEvent) {
      try {
        element.detachEvent('on' + name, observer);
      } catch (e) {}
    }
  }
});

/* prevent memory leaks in IE */
if (navigator.appVersion.match(/\bMSIE\b/))
  Event.observe(window, 'unload', Event.unloadCache, false);
var Position = {
  // set to true if needed, warning: firefox performance problems
  // NOT neeeded for page scrolling, only if draggable contained in
  // scrollable elements
  includeScrollOffsets: false,

  // must be called before calling withinIncludingScrolloffset, every time the
  // page is scrolled
  prepare: function() {
    this.deltaX =  window.pageXOffset
                || document.documentElement.scrollLeft
                || document.body.scrollLeft
                || 0;
    this.deltaY =  window.pageYOffset
                || document.documentElement.scrollTop
                || document.body.scrollTop
                || 0;
  },

  realOffset: function(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.scrollTop  || 0;
      valueL += element.scrollLeft || 0;
      element = element.parentNode;
    } while (element);
    return [valueL, valueT];
  },

  cumulativeOffset: function(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;
      element = element.offsetParent;
    } while (element);
    return [valueL, valueT];
  },

  positionedOffset: function(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;
      element = element.offsetParent;
      if (element) {
        if(element.tagName=='BODY') break;
        var p = Element.getStyle(element, 'position');
        if (p == 'relative' || p == 'absolute') break;
      }
    } while (element);
    return [valueL, valueT];
  },

  offsetParent: function(element) {
    if (element.offsetParent) return element.offsetParent;
    if (element == document.body) return element;

    while ((element = element.parentNode) && element != document.body)
      if (Element.getStyle(element, 'position') != 'static')
        return element;

    return document.body;
  },

  // caches x/y coordinate pair to use with overlap
  within: function(element, x, y) {
    if (this.includeScrollOffsets)
      return this.withinIncludingScrolloffsets(element, x, y);
    this.xcomp = x;
    this.ycomp = y;
    this.offset = this.cumulativeOffset(element);

    return (y >= this.offset[1] &&
            y <  this.offset[1] + element.offsetHeight &&
            x >= this.offset[0] &&
            x <  this.offset[0] + element.offsetWidth);
  },

  withinIncludingScrolloffsets: function(element, x, y) {
    var offsetcache = this.realOffset(element);

    this.xcomp = x + offsetcache[0] - this.deltaX;
    this.ycomp = y + offsetcache[1] - this.deltaY;
    this.offset = this.cumulativeOffset(element);

    return (this.ycomp >= this.offset[1] &&
            this.ycomp <  this.offset[1] + element.offsetHeight &&
            this.xcomp >= this.offset[0] &&
            this.xcomp <  this.offset[0] + element.offsetWidth);
  },

  // within must be called directly before
  overlap: function(mode, element) {
    if (!mode) return 0;
    if (mode == 'vertical')
      return ((this.offset[1] + element.offsetHeight) - this.ycomp) /
        element.offsetHeight;
    if (mode == 'horizontal')
      return ((this.offset[0] + element.offsetWidth) - this.xcomp) /
        element.offsetWidth;
  },

  page: function(forElement) {
    var valueT = 0, valueL = 0;

    var element = forElement;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;

      // Safari fix
      if (element.offsetParent==document.body)
        if (Element.getStyle(element,'position')=='absolute') break;

    } while (element = element.offsetParent);

    element = forElement;
    do {
      if (!window.opera || element.tagName=='BODY') {
        valueT -= element.scrollTop  || 0;
        valueL -= element.scrollLeft || 0;
      }
    } while (element = element.parentNode);

    return [valueL, valueT];
  },

  clone: function(source, target) {
    var options = Object.extend({
      setLeft:    true,
      setTop:     true,
      setWidth:   true,
      setHeight:  true,
      offsetTop:  0,
      offsetLeft: 0
    }, arguments[2] || {})

    // find page position of source
    source = $(source);
    var p = Position.page(source);

    // find coordinate system to use
    target = $(target);
    var delta = [0, 0];
    var parent = null;
    // delta [0,0] will do fine with position: fixed elements,
    // position:absolute needs offsetParent deltas
    if (Element.getStyle(target,'position') == 'absolute') {
      parent = Position.offsetParent(target);
      delta = Position.page(parent);
    }

    // correct by body offsets (fixes Safari)
    if (parent == document.body) {
      delta[0] -= document.body.offsetLeft;
      delta[1] -= document.body.offsetTop;
    }

    // set position
    if(options.setLeft)   target.style.left  = (p[0] - delta[0] + options.offsetLeft) + 'px';
    if(options.setTop)    target.style.top   = (p[1] - delta[1] + options.offsetTop) + 'px';
    if(options.setWidth)  target.style.width = source.offsetWidth + 'px';
    if(options.setHeight) target.style.height = source.offsetHeight + 'px';
  },

  absolutize: function(element) {
    element = $(element);
    if (element.style.position == 'absolute') return;
    Position.prepare();

    var offsets = Position.positionedOffset(element);
    var top     = offsets[1];
    var left    = offsets[0];
    var width   = element.clientWidth;
    var height  = element.clientHeight;

    element._originalLeft   = left - parseFloat(element.style.left  || 0);
    element._originalTop    = top  - parseFloat(element.style.top || 0);
    element._originalWidth  = element.style.width;
    element._originalHeight = element.style.height;

    element.style.position = 'absolute';
    element.style.top    = top + 'px';
    element.style.left   = left + 'px';
    element.style.width  = width + 'px';
    element.style.height = height + 'px';
  },

  relativize: function(element) {
    element = $(element);
    if (element.style.position == 'relative') return;
    Position.prepare();

    element.style.position = 'relative';
    var top  = parseFloat(element.style.top  || 0) - (element._originalTop || 0);
    var left = parseFloat(element.style.left || 0) - (element._originalLeft || 0);

    element.style.top    = top + 'px';
    element.style.left   = left + 'px';
    element.style.height = element._originalHeight;
    element.style.width  = element._originalWidth;
  }
}

// Safari returns margins on body which is incorrect if the child is absolutely
// positioned.  For performance reasons, redefine Position.cumulativeOffset for
// KHTML/WebKit only.
if (/Konqueror|Safari|KHTML/.test(navigator.userAgent)) {
  Position.cumulativeOffset = function(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;
      if (element.offsetParent == document.body)
        if (Element.getStyle(element, 'position') == 'absolute') break;

      element = element.offsetParent;
    } while (element);

    return [valueL, valueT];
  }
}

Element.addMethods();

// script.aculo.us scriptaculous.js v1.7.0, Fri Jan 19 19:16:36 CET 2007

// Copyright (c) 2005, 2006 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// For details, see the script.aculo.us web site: http://script.aculo.us/

var Scriptaculous = {
  Version: '1.7.0',
  require: function(libraryName) {
    // inserting via DOM fails in Safari 2.0, so brute force approach
    document.write('<script type="text/javascript" src="'+libraryName+'"></script>');
  },
  load: function() {
    if((typeof Prototype=='undefined') || 
       (typeof Element == 'undefined') || 
       (typeof Element.Methods=='undefined') ||
       parseFloat(Prototype.Version.split(".")[0] + "." +
                  Prototype.Version.split(".")[1]) < 1.5)
       throw("script.aculo.us requires the Prototype JavaScript framework >= 1.5.0");
    
    $A(document.getElementsByTagName("script")).findAll( function(s) {
      return (s.src && s.src.match(/merged-common\.js(\?.*)?$/))
    }).each( function(s) {
      var path = s.src.replace(/merged-common\.js(\?.*)?$/,'');
      var includes = s.src.match(/\?.*load=([a-z,]*)/);
      (includes ? includes[1] : 'effects,slider').split(',').each(
       function(include) { Scriptaculous.require(path+include+'.js') });
    });
  }
}

//Scriptaculous.load();

// script.aculo.us effects.js v1.7.0, Fri Jan 19 19:16:36 CET 2007

// Copyright (c) 2005, 2006 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
// Contributors:
//  Justin Palmer (http://encytemedia.com/)
//  Mark Pilgrim (http://diveintomark.org/)
//  Martin Bialasinki
// 
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/ 

// converts rgb() and #xxx to #xxxxxx format,  
// returns self (or first argument) if not convertable  
String.prototype.parseColor = function() {  
  var color = '#';
  if(this.slice(0,4) == 'rgb(') {  
    var cols = this.slice(4,this.length-1).split(',');  
    var i=0; do { color += parseInt(cols[i]).toColorPart() } while (++i<3);  
  } else {  
    if(this.slice(0,1) == '#') {  
      if(this.length==4) for(var i=1;i<4;i++) color += (this.charAt(i) + this.charAt(i)).toLowerCase();  
      if(this.length==7) color = this.toLowerCase();  
    }  
  }  
  return(color.length==7 ? color : (arguments[0] || this));  
}

/*--------------------------------------------------------------------------*/

Element.collectTextNodes = function(element) {  
  return $A($(element).childNodes).collect( function(node) {
    return (node.nodeType==3 ? node.nodeValue : 
      (node.hasChildNodes() ? Element.collectTextNodes(node) : ''));
  }).flatten().join('');
}

Element.collectTextNodesIgnoreClass = function(element, className) {  
  return $A($(element).childNodes).collect( function(node) {
    return (node.nodeType==3 ? node.nodeValue : 
      ((node.hasChildNodes() && !Element.hasClassName(node,className)) ? 
        Element.collectTextNodesIgnoreClass(node, className) : ''));
  }).flatten().join('');
}

Element.setContentZoom = function(element, percent) {
  element = $(element);  
  element.setStyle({fontSize: (percent/100) + 'em'});   
  if(navigator.appVersion.indexOf('AppleWebKit')>0) window.scrollBy(0,0);
  return element;
}

Element.getOpacity = function(element){
  return $(element).getStyle('opacity');
}

Element.setOpacity = function(element, value){
  return $(element).setStyle({opacity:value});
}

Element.getInlineOpacity = function(element){
  return $(element).style.opacity || '';
}

Element.forceRerendering = function(element) {
  try {
    element = $(element);
    var n = document.createTextNode(' ');
    element.appendChild(n);
    element.removeChild(n);
  } catch(e) { }
};

/*--------------------------------------------------------------------------*/

Array.prototype.call = function() {
  var args = arguments;
  this.each(function(f){ f.apply(this, args) });
}

/*--------------------------------------------------------------------------*/

var Effect = {
  _elementDoesNotExistError: {
    name: 'ElementDoesNotExistError',
    message: 'The specified DOM element does not exist, but is required for this effect to operate'
  },
  tagifyText: function(element) {
    if(typeof Builder == 'undefined')
      throw("Effect.tagifyText requires including script.aculo.us' builder.js library");
      
    var tagifyStyle = 'position:relative';
    if(/MSIE/.test(navigator.userAgent) && !window.opera) tagifyStyle += ';zoom:1';
    
    element = $(element);
    $A(element.childNodes).each( function(child) {
      if(child.nodeType==3) {
        child.nodeValue.toArray().each( function(character) {
          element.insertBefore(
            Builder.node('span',{style: tagifyStyle},
              character == ' ' ? String.fromCharCode(160) : character), 
              child);
        });
        Element.remove(child);
      }
    });
  },
  multiple: function(element, effect) {
    var elements;
    if(((typeof element == 'object') || 
        (typeof element == 'function')) && 
       (element.length))
      elements = element;
    else
      elements = $(element).childNodes;
      
    var options = Object.extend({
      speed: 0.1,
      delay: 0.0
    }, arguments[2] || {});
    var masterDelay = options.delay;

    $A(elements).each( function(element, index) {
      new effect(element, Object.extend(options, { delay: index * options.speed + masterDelay }));
    });
  },
  PAIRS: {
    'slide':  ['SlideDown','SlideUp'],
    'blind':  ['BlindDown','BlindUp'],
    'appear': ['Appear','Fade']
  },
  toggle: function(element, effect) {
    element = $(element);
    effect = (effect || 'appear').toLowerCase();
    var options = Object.extend({
      queue: { position:'end', scope:(element.id || 'global'), limit: 1 }
    }, arguments[2] || {});
    Effect[element.visible() ? 
      Effect.PAIRS[effect][1] : Effect.PAIRS[effect][0]](element, options);
  }
};

var Effect2 = Effect; // deprecated

/* ------------- transitions ------------- */

Effect.Transitions = {
  linear: Prototype.K,
  sinoidal: function(pos) {
    return (-Math.cos(pos*Math.PI)/2) + 0.5;
  },
  reverse: function(pos) {
    return 1-pos;
  },
  flicker: function(pos) {
    return ((-Math.cos(pos*Math.PI)/4) + 0.75) + Math.random()/4;
  },
  wobble: function(pos) {
    return (-Math.cos(pos*Math.PI*(9*pos))/2) + 0.5;
  },
  pulse: function(pos, pulses) { 
    pulses = pulses || 5; 
    return (
      Math.round((pos % (1/pulses)) * pulses) == 0 ? 
            ((pos * pulses * 2) - Math.floor(pos * pulses * 2)) : 
        1 - ((pos * pulses * 2) - Math.floor(pos * pulses * 2))
      );
  },
  none: function(pos) {
    return 0;
  },
  full: function(pos) {
    return 1;
  }
};

/* ------------- core effects ------------- */

Effect.ScopedQueue = Class.create();
Object.extend(Object.extend(Effect.ScopedQueue.prototype, Enumerable), {
  initialize: function() {
    this.effects  = [];
    this.interval = null;
  },
  _each: function(iterator) {
    this.effects._each(iterator);
  },
  add: function(effect) {
    var timestamp = new Date().getTime();
    
    var position = (typeof effect.options.queue == 'string') ? 
      effect.options.queue : effect.options.queue.position;
    
    switch(position) {
      case 'front':
        // move unstarted effects after this effect  
        this.effects.findAll(function(e){ return e.state=='idle' }).each( function(e) {
            e.startOn  += effect.finishOn;
            e.finishOn += effect.finishOn;
          });
        break;
      case 'with-last':
        timestamp = this.effects.pluck('startOn').max() || timestamp;
        break;
      case 'end':
        // start effect after last queued effect has finished
        timestamp = this.effects.pluck('finishOn').max() || timestamp;
        break;
    }
    
    effect.startOn  += timestamp;
    effect.finishOn += timestamp;

    if(!effect.options.queue.limit || (this.effects.length < effect.options.queue.limit))
      this.effects.push(effect);
    
    if(!this.interval) 
      this.interval = setInterval(this.loop.bind(this), 15);
  },
  remove: function(effect) {
    this.effects = this.effects.reject(function(e) { return e==effect });
    if(this.effects.length == 0) {
      clearInterval(this.interval);
      this.interval = null;
    }
  },
  loop: function() {
    var timePos = new Date().getTime();
    for(var i=0, len=this.effects.length;i<len;i++) 
      if(this.effects[i]) this.effects[i].loop(timePos);
  }
});

Effect.Queues = {
  instances: $H(),
  get: function(queueName) {
    if(typeof queueName != 'string') return queueName;
    
    if(!this.instances[queueName])
      this.instances[queueName] = new Effect.ScopedQueue();
      
    return this.instances[queueName];
  }
}
Effect.Queue = Effect.Queues.get('global');

Effect.DefaultOptions = {
  transition: Effect.Transitions.sinoidal,
  duration:   1.0,   // seconds
  fps:        60.0,  // max. 60fps due to Effect.Queue implementation
  sync:       false, // true for combining
  from:       0.0,
  to:         1.0,
  delay:      0.0,
  queue:      'parallel'
}

Effect.Base = function() {};
Effect.Base.prototype = {
  position: null,
  start: function(options) {
    this.options      = Object.extend(Object.extend({},Effect.DefaultOptions), options || {});
    this.currentFrame = 0;
    this.state        = 'idle';
    this.startOn      = this.options.delay*1000;
    this.finishOn     = this.startOn + (this.options.duration*1000);
    this.event('beforeStart');
    if(!this.options.sync)
      Effect.Queues.get(typeof this.options.queue == 'string' ? 
        'global' : this.options.queue.scope).add(this);
  },
  loop: function(timePos) {
    if(timePos >= this.startOn) {
      if(timePos >= this.finishOn) {
        this.render(1.0);
        this.cancel();
        this.event('beforeFinish');
        if(this.finish) this.finish(); 
        this.event('afterFinish');
        return;  
      }
      var pos   = (timePos - this.startOn) / (this.finishOn - this.startOn);
      var frame = Math.round(pos * this.options.fps * this.options.duration);
      if(frame > this.currentFrame) {
        this.render(pos);
        this.currentFrame = frame;
      }
    }
  },
  render: function(pos) {
    if(this.state == 'idle') {
      this.state = 'running';
      this.event('beforeSetup');
      if(this.setup) this.setup();
      this.event('afterSetup');
    }
    if(this.state == 'running') {
      if(this.options.transition) pos = this.options.transition(pos);
      pos *= (this.options.to-this.options.from);
      pos += this.options.from;
      this.position = pos;
      this.event('beforeUpdate');
      if(this.update) this.update(pos);
      this.event('afterUpdate');
    }
  },
  cancel: function() {
    if(!this.options.sync)
      Effect.Queues.get(typeof this.options.queue == 'string' ? 
        'global' : this.options.queue.scope).remove(this);
    this.state = 'finished';
  },
  event: function(eventName) {
    if(this.options[eventName + 'Internal']) this.options[eventName + 'Internal'](this);
    if(this.options[eventName]) this.options[eventName](this);
  },
  inspect: function() {
    var data = $H();
    for(property in this)
      if(typeof this[property] != 'function') data[property] = this[property];
    return '#<Effect:' + data.inspect() + ',options:' + $H(this.options).inspect() + '>';
  }
}

Effect.Parallel = Class.create();
Object.extend(Object.extend(Effect.Parallel.prototype, Effect.Base.prototype), {
  initialize: function(effects) {
    this.effects = effects || [];
    this.start(arguments[1]);
  },
  update: function(position) {
    this.effects.invoke('render', position);
  },
  finish: function(position) {
    this.effects.each( function(effect) {
      effect.render(1.0);
      effect.cancel();
      effect.event('beforeFinish');
      if(effect.finish) effect.finish(position);
      effect.event('afterFinish');
    });
  }
});

Effect.Event = Class.create();
Object.extend(Object.extend(Effect.Event.prototype, Effect.Base.prototype), {
  initialize: function() {
    var options = Object.extend({
      duration: 0
    }, arguments[0] || {});
    this.start(options);
  },
  update: Prototype.emptyFunction
});

Effect.Opacity = Class.create();
Object.extend(Object.extend(Effect.Opacity.prototype, Effect.Base.prototype), {
  initialize: function(element) {
    this.element = $(element);
    if(!this.element) throw(Effect._elementDoesNotExistError);
    // make this work on IE on elements without 'layout'
    if(/MSIE/.test(navigator.userAgent) && !window.opera && (!this.element.currentStyle.hasLayout))
      this.element.setStyle({zoom: 1});
    var options = Object.extend({
      from: this.element.getOpacity() || 0.0,
      to:   1.0
    }, arguments[1] || {});
    this.start(options);
  },
  update: function(position) {
    this.element.setOpacity(position);
  }
});

Effect.Move = Class.create();
Object.extend(Object.extend(Effect.Move.prototype, Effect.Base.prototype), {
  initialize: function(element) {
    this.element = $(element);
    if(!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      x:    0,
      y:    0,
      mode: 'relative'
    }, arguments[1] || {});
    this.start(options);
  },
  setup: function() {
    // Bug in Opera: Opera returns the "real" position of a static element or
    // relative element that does not have top/left explicitly set.
    // ==> Always set top and left for position relative elements in your stylesheets 
    // (to 0 if you do not need them) 
    this.element.makePositioned();
    this.originalLeft = parseFloat(this.element.getStyle('left') || '0');
    this.originalTop  = parseFloat(this.element.getStyle('top')  || '0');
    if(this.options.mode == 'absolute') {
      // absolute movement, so we need to calc deltaX and deltaY
      this.options.x = this.options.x - this.originalLeft;
      this.options.y = this.options.y - this.originalTop;
    }
  },
  update: function(position) {
    this.element.setStyle({
      left: Math.round(this.options.x  * position + this.originalLeft) + 'px',
      top:  Math.round(this.options.y  * position + this.originalTop)  + 'px'
    });
  }
});

// for backwards compatibility
Effect.MoveBy = function(element, toTop, toLeft) {
  return new Effect.Move(element, 
    Object.extend({ x: toLeft, y: toTop }, arguments[3] || {}));
};

Effect.Scale = Class.create();
Object.extend(Object.extend(Effect.Scale.prototype, Effect.Base.prototype), {
  initialize: function(element, percent) {
    this.element = $(element);
    if(!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      scaleX: true,
      scaleY: true,
      scaleContent: true,
      scaleFromCenter: false,
      scaleMode: 'box',        // 'box' or 'contents' or {} with provided values
      scaleFrom: 100.0,
      scaleTo:   percent
    }, arguments[2] || {});
    this.start(options);
  },
  setup: function() {
    this.restoreAfterFinish = this.options.restoreAfterFinish || false;
    this.elementPositioning = this.element.getStyle('position');
    this.originalStyle = {};
    ['top','left','width','height','fontSize'].each( function(k) {
      this.originalStyle[k] = this.element.style[k];
    }.bind(this));
    this.originalTop  = this.element.offsetTop;
    this.originalLeft = this.element.offsetLeft;
    var fontSize = this.element.getStyle('font-size') || '100%';
    ['em','px','%','pt'].each( function(fontSizeType) {
      if(fontSize.indexOf(fontSizeType)>0) {
        this.fontSize     = parseFloat(fontSize);
        this.fontSizeType = fontSizeType;
      }
    }.bind(this));
    
    this.factor = (this.options.scaleTo - this.options.scaleFrom)/100;
    this.dims = null;
    if(this.options.scaleMode=='box')
      this.dims = [this.element.offsetHeight, this.element.offsetWidth];
    if(/^content/.test(this.options.scaleMode))
      this.dims = [this.element.scrollHeight, this.element.scrollWidth];
    if(!this.dims)
      this.dims = [this.options.scaleMode.originalHeight,
                   this.options.scaleMode.originalWidth];
  },
  update: function(position) {
    var currentScale = (this.options.scaleFrom/100.0) + (this.factor * position);
    if(this.options.scaleContent && this.fontSize)
      this.element.setStyle({fontSize: this.fontSize * currentScale + this.fontSizeType });
    this.setDimensions(this.dims[0] * currentScale, this.dims[1] * currentScale);
  },
  finish: function(position) {
    if(this.restoreAfterFinish) this.element.setStyle(this.originalStyle);
  },
  setDimensions: function(height, width) {
    var d = {};
    if(this.options.scaleX && !isNaN(width)) 
    {	
    	d.width = Math.round(width) + 'px';
    }
    if(this.options.scaleY && !isNaN(height)) 
    {
    	d.height = Math.round(height) + 'px';
    }
    
    if(this.options.scaleFromCenter) {
      var topd  = (height - this.dims[0])/2;
      var leftd = (width  - this.dims[1])/2;
      if(this.elementPositioning == 'absolute') {
        if(this.options.scaleY) d.top = this.originalTop-topd + 'px';
        if(this.options.scaleX) d.left = this.originalLeft-leftd + 'px';
      } else {
        if(this.options.scaleY) d.top = -topd + 'px';
        if(this.options.scaleX) d.left = -leftd + 'px';
      }
    }

   	this.element.setStyle(d);
  }
});

Effect.Highlight = Class.create();
Object.extend(Object.extend(Effect.Highlight.prototype, Effect.Base.prototype), {
  initialize: function(element) {
    this.element = $(element);
    if(!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({ startcolor: '#ffff99' }, arguments[1] || {});
    this.start(options);
  },
  setup: function() {
    // Prevent executing on elements not in the layout flow
    if(this.element.getStyle('display')=='none') { this.cancel(); return; }
    // Disable background image during the effect
    this.oldStyle = {};
    if (!this.options.keepBackgroundImage) {
      this.oldStyle.backgroundImage = this.element.getStyle('background-image');
      this.element.setStyle({backgroundImage: 'none'});
    }
    if(!this.options.endcolor)
      this.options.endcolor = this.element.getStyle('background-color').parseColor('#ffffff');
    if(!this.options.restorecolor)
      this.options.restorecolor = this.element.getStyle('background-color');
    // init color calculations
    this._base  = $R(0,2).map(function(i){ return parseInt(this.options.startcolor.slice(i*2+1,i*2+3),16) }.bind(this));
    this._delta = $R(0,2).map(function(i){ return parseInt(this.options.endcolor.slice(i*2+1,i*2+3),16)-this._base[i] }.bind(this));
  },
  update: function(position) {
    this.element.setStyle({backgroundColor: $R(0,2).inject('#',function(m,v,i){
      return m+(Math.round(this._base[i]+(this._delta[i]*position)).toColorPart()); }.bind(this)) });
  },
  finish: function() {
    this.element.setStyle(Object.extend(this.oldStyle, {
      backgroundColor: this.options.restorecolor
    }));
  }
});

Effect.ScrollTo = Class.create();
Object.extend(Object.extend(Effect.ScrollTo.prototype, Effect.Base.prototype), {
  initialize: function(element) {
    this.element = $(element);
    this.start(arguments[1] || {});
  },
  setup: function() {
    Position.prepare();
    var offsets = Position.cumulativeOffset(this.element);
    if(this.options.offset) offsets[1] += this.options.offset;
    var max = window.innerHeight ? 
      window.height - window.innerHeight :
      document.body.scrollHeight - 
        (document.documentElement.clientHeight ? 
          document.documentElement.clientHeight : document.body.clientHeight);
    this.scrollStart = Position.deltaY;
    this.delta = (offsets[1] > max ? max : offsets[1]) - this.scrollStart;
  },
  update: function(position) {
    Position.prepare();
    window.scrollTo(Position.deltaX, 
      this.scrollStart + (position*this.delta));
  }
});

/* ------------- combination effects ------------- */

Effect.Fade = function(element) {
  element = $(element);
  var oldOpacity = element.getInlineOpacity();
  var options = Object.extend({
  from: element.getOpacity() || 1.0,
  to:   0.0,
  afterFinishInternal: function(effect) { 
    if(effect.options.to!=0) return;
    effect.element.hide().setStyle({opacity: oldOpacity}); 
  }}, arguments[1] || {});
  return new Effect.Opacity(element,options);
}

Effect.Appear = function(element) {
  element = $(element);
  var options = Object.extend({
  from: (element.getStyle('display') == 'none' ? 0.0 : element.getOpacity() || 0.0),
  to:   1.0,
  // force Safari to render floated elements properly
  afterFinishInternal: function(effect) {
    effect.element.forceRerendering();
  },
  beforeSetup: function(effect) {
    effect.element.setOpacity(effect.options.from).show(); 
  }}, arguments[1] || {});
  return new Effect.Opacity(element,options);
}

Effect.Puff = function(element) {
  element = $(element);
  var oldStyle = { 
    opacity: element.getInlineOpacity(), 
    position: element.getStyle('position'),
    top:  element.style.top,
    left: element.style.left,
    width: element.style.width,
    height: element.style.height
  };
  return new Effect.Parallel(
   [ new Effect.Scale(element, 200, 
      { sync: true, scaleFromCenter: true, scaleContent: true, restoreAfterFinish: true }), 
     new Effect.Opacity(element, { sync: true, to: 0.0 } ) ], 
     Object.extend({ duration: 1.0, 
      beforeSetupInternal: function(effect) {
        Position.absolutize(effect.effects[0].element)
      },
      afterFinishInternal: function(effect) {
         effect.effects[0].element.hide().setStyle(oldStyle); }
     }, arguments[1] || {})
   );
}

Effect.BlindUp = function(element) {
  element = $(element);
  element.makeClipping();
  return new Effect.Scale(element, 0,
    Object.extend({ scaleContent: false, 
      scaleX: false, 
      restoreAfterFinish: true,
      afterFinishInternal: function(effect) {
        effect.element.hide().undoClipping();
      } 
    }, arguments[1] || {})
  );
}

Effect.BlindDown = function(element) {
  element = $(element);
  var elementDimensions = element.getDimensions();
  return new Effect.Scale(element, 100, Object.extend({ 
    scaleContent: false, 
    scaleX: false,
    scaleFrom: 0,
    scaleMode: {originalHeight: elementDimensions.height, originalWidth: elementDimensions.width},
    restoreAfterFinish: true,
    afterSetup: function(effect) {
      effect.element.makeClipping().setStyle({height: '0px'}).show(); 
    },  
    afterFinishInternal: function(effect) {
      effect.element.undoClipping();
    }
  }, arguments[1] || {}));
}

Effect.SwitchOff = function(element) {
  element = $(element);
  var oldOpacity = element.getInlineOpacity();
  return new Effect.Appear(element, Object.extend({
    duration: 0.4,
    from: 0,
    transition: Effect.Transitions.flicker,
    afterFinishInternal: function(effect) {
      new Effect.Scale(effect.element, 1, { 
        duration: 0.3, scaleFromCenter: true,
        scaleX: false, scaleContent: false, restoreAfterFinish: true,
        beforeSetup: function(effect) { 
          effect.element.makePositioned().makeClipping();
        },
        afterFinishInternal: function(effect) {
          effect.element.hide().undoClipping().undoPositioned().setStyle({opacity: oldOpacity});
        }
      })
    }
  }, arguments[1] || {}));
}

Effect.DropOut = function(element) {
  element = $(element);
  var oldStyle = {
    top: element.getStyle('top'),
    left: element.getStyle('left'),
    opacity: element.getInlineOpacity() };
  return new Effect.Parallel(
    [ new Effect.Move(element, {x: 0, y: 100, sync: true }), 
      new Effect.Opacity(element, { sync: true, to: 0.0 }) ],
    Object.extend(
      { duration: 0.5,
        beforeSetup: function(effect) {
          effect.effects[0].element.makePositioned(); 
        },
        afterFinishInternal: function(effect) {
          effect.effects[0].element.hide().undoPositioned().setStyle(oldStyle);
        } 
      }, arguments[1] || {}));
}

Effect.Shake = function(element) {
  element = $(element);
  var oldStyle = {
    top: element.getStyle('top'),
    left: element.getStyle('left') };
    return new Effect.Move(element, 
      { x:  20, y: 0, duration: 0.05, afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -40, y: 0, duration: 0.1,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x:  40, y: 0, duration: 0.1,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -40, y: 0, duration: 0.1,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x:  40, y: 0, duration: 0.1,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -20, y: 0, duration: 0.05, afterFinishInternal: function(effect) {
        effect.element.undoPositioned().setStyle(oldStyle);
  }}) }}) }}) }}) }}) }});
}

Effect.SlideDown = function(element) {
  element = $(element).cleanWhitespace();
  // SlideDown need to have the content of the element wrapped in a container element with fixed height!
  var oldInnerBottom = element.down().getStyle('bottom');
  var elementDimensions = element.getDimensions();
  return new Effect.Scale(element, 100, Object.extend({ 
    scaleContent: false, 
    scaleX: false, 
    scaleFrom: window.opera ? 0 : 1,
    scaleMode: {originalHeight: elementDimensions.height, originalWidth: elementDimensions.width},
    restoreAfterFinish: true,
    afterSetup: function(effect) {
      effect.element.makePositioned();
      effect.element.down().makePositioned();
      if(window.opera) effect.element.setStyle({top: ''});
      effect.element.makeClipping().setStyle({height: '0px'}).show(); 
    },
    afterUpdateInternal: function(effect) {
      effect.element.down().setStyle({bottom:
        (effect.dims[0] - effect.element.clientHeight) + 'px' }); 
    },
    afterFinishInternal: function(effect) {
      effect.element.undoClipping().undoPositioned();
      effect.element.down().undoPositioned().setStyle({bottom: oldInnerBottom}); }
    }, arguments[1] || {})
  );
}

Effect.SlideUp = function(element) {
  element = $(element).cleanWhitespace();
  var oldInnerBottom = element.down().getStyle('bottom');
  return new Effect.Scale(element, window.opera ? 0 : 1,
   Object.extend({ scaleContent: false, 
    scaleX: false, 
    scaleMode: 'box',
    scaleFrom: 100,
    restoreAfterFinish: true,
    beforeStartInternal: function(effect) {
      effect.element.makePositioned();
      effect.element.down().makePositioned();
      if(window.opera) effect.element.setStyle({top: ''});
      effect.element.makeClipping().show();
    },  
    afterUpdateInternal: function(effect) {
      effect.element.down().setStyle({bottom:
        (effect.dims[0] - effect.element.clientHeight) + 'px' });
    },
    afterFinishInternal: function(effect) {
      effect.element.hide().undoClipping().undoPositioned().setStyle({bottom: oldInnerBottom});
      effect.element.down().undoPositioned();
    }
   }, arguments[1] || {})
  );
}

// Bug in opera makes the TD containing this element expand for a instance after finish 
Effect.Squish = function(element) {
  return new Effect.Scale(element, window.opera ? 1 : 0, { 
    restoreAfterFinish: true,
    beforeSetup: function(effect) {
      effect.element.makeClipping(); 
    },  
    afterFinishInternal: function(effect) {
      effect.element.hide().undoClipping(); 
    }
  });
}

Effect.Grow = function(element) {
  element = $(element);
  var options = Object.extend({
    direction: 'center',
    moveTransition: Effect.Transitions.sinoidal,
    scaleTransition: Effect.Transitions.sinoidal,
    opacityTransition: Effect.Transitions.full
  }, arguments[1] || {});
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    height: element.style.height,
    width: element.style.width,
    opacity: element.getInlineOpacity() };

  var dims = element.getDimensions();    
  var initialMoveX, initialMoveY;
  var moveX, moveY;
  
  switch (options.direction) {
    case 'top-left':
      initialMoveX = initialMoveY = moveX = moveY = 0; 
      break;
    case 'top-right':
      initialMoveX = dims.width;
      initialMoveY = moveY = 0;
      moveX = -dims.width;
      break;
    case 'bottom-left':
      initialMoveX = moveX = 0;
      initialMoveY = dims.height;
      moveY = -dims.height;
      break;
    case 'bottom-right':
      initialMoveX = dims.width;
      initialMoveY = dims.height;
      moveX = -dims.width;
      moveY = -dims.height;
      break;
    case 'center':
      initialMoveX = dims.width / 2;
      initialMoveY = dims.height / 2;
      moveX = -dims.width / 2;
      moveY = -dims.height / 2;
      break;
  }
  
  return new Effect.Move(element, {
    x: initialMoveX,
    y: initialMoveY,
    duration: 0.01, 
    beforeSetup: function(effect) {
      effect.element.hide().makeClipping().makePositioned();
    },
    afterFinishInternal: function(effect) {
      new Effect.Parallel(
        [ new Effect.Opacity(effect.element, { sync: true, to: 1.0, from: 0.0, transition: options.opacityTransition }),
          new Effect.Move(effect.element, { x: moveX, y: moveY, sync: true, transition: options.moveTransition }),
          new Effect.Scale(effect.element, 100, {
            scaleMode: { originalHeight: dims.height, originalWidth: dims.width }, 
            sync: true, scaleFrom: window.opera ? 1 : 0, transition: options.scaleTransition, restoreAfterFinish: true})
        ], Object.extend({
             beforeSetup: function(effect) {
               effect.effects[0].element.setStyle({height: '0px'}).show(); 
             },
             afterFinishInternal: function(effect) {
               effect.effects[0].element.undoClipping().undoPositioned().setStyle(oldStyle); 
             }
           }, options)
      )
    }
  });
}

Effect.Shrink = function(element) {
  element = $(element);
  var options = Object.extend({
    direction: 'center',
    moveTransition: Effect.Transitions.sinoidal,
    scaleTransition: Effect.Transitions.sinoidal,
    opacityTransition: Effect.Transitions.none
  }, arguments[1] || {});
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    height: element.style.height,
    width: element.style.width,
    opacity: element.getInlineOpacity() };

  var dims = element.getDimensions();
  var moveX, moveY;
  
  switch (options.direction) {
    case 'top-left':
      moveX = moveY = 0;
      break;
    case 'top-right':
      moveX = dims.width;
      moveY = 0;
      break;
    case 'bottom-left':
      moveX = 0;
      moveY = dims.height;
      break;
    case 'bottom-right':
      moveX = dims.width;
      moveY = dims.height;
      break;
    case 'center':  
      moveX = dims.width / 2;
      moveY = dims.height / 2;
      break;
  }
  
  return new Effect.Parallel(
    [ new Effect.Opacity(element, { sync: true, to: 0.0, from: 1.0, transition: options.opacityTransition }),
      new Effect.Scale(element, window.opera ? 1 : 0, { sync: true, transition: options.scaleTransition, restoreAfterFinish: true}),
      new Effect.Move(element, { x: moveX, y: moveY, sync: true, transition: options.moveTransition })
    ], Object.extend({            
         beforeStartInternal: function(effect) {
           effect.effects[0].element.makePositioned().makeClipping(); 
         },
         afterFinishInternal: function(effect) {
           effect.effects[0].element.hide().undoClipping().undoPositioned().setStyle(oldStyle); }
       }, options)
  );
}

Effect.Pulsate = function(element) {
  element = $(element);
  var options    = arguments[1] || {};
  var oldOpacity = element.getInlineOpacity();
  var transition = options.transition || Effect.Transitions.sinoidal;
  var reverser   = function(pos){ return transition(1-Effect.Transitions.pulse(pos, options.pulses)) };
  reverser.bind(transition);
  return new Effect.Opacity(element, 
    Object.extend(Object.extend({  duration: 2.0, from: 0,
      afterFinishInternal: function(effect) { effect.element.setStyle({opacity: oldOpacity}); }
    }, options), {transition: reverser}));
}

Effect.Fold = function(element) {
  element = $(element);
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    width: element.style.width,
    height: element.style.height };
  element.makeClipping();
  return new Effect.Scale(element, 5, Object.extend({   
    scaleContent: false,
    scaleX: false,
    afterFinishInternal: function(effect) {
    new Effect.Scale(element, 1, { 
      scaleContent: false, 
      scaleY: false,
      afterFinishInternal: function(effect) {
        effect.element.hide().undoClipping().setStyle(oldStyle);
      } });
  }}, arguments[1] || {}));
};

Effect.Morph = Class.create();
Object.extend(Object.extend(Effect.Morph.prototype, Effect.Base.prototype), {
  initialize: function(element) {
    this.element = $(element);
    if(!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      style: {}
    }, arguments[1] || {});
    if (typeof options.style == 'string') {
      if(options.style.indexOf(':') == -1) {
        var cssText = '', selector = '.' + options.style;
        $A(document.styleSheets).reverse().each(function(styleSheet) {
          if (styleSheet.cssRules) cssRules = styleSheet.cssRules;
          else if (styleSheet.rules) cssRules = styleSheet.rules;
          $A(cssRules).reverse().each(function(rule) {
            if (selector == rule.selectorText) {
              cssText = rule.style.cssText;
              throw $break;
            }
          });
          if (cssText) throw $break;
        });
        this.style = cssText.parseStyle();
        options.afterFinishInternal = function(effect){
          effect.element.addClassName(effect.options.style);
          effect.transforms.each(function(transform) {
            if(transform.style != 'opacity')
              effect.element.style[transform.style.camelize()] = '';
          });
        }
      } else this.style = options.style.parseStyle();
    } else this.style = $H(options.style)
    this.start(options);
  },
  setup: function(){
    function parseColor(color){
      if(!color || ['rgba(0, 0, 0, 0)','transparent'].include(color)) color = '#ffffff';
      color = color.parseColor();
      return $R(0,2).map(function(i){
        return parseInt( color.slice(i*2+1,i*2+3), 16 ) 
      });
    }
    this.transforms = this.style.map(function(pair){
      var property = pair[0].underscore().dasherize(), value = pair[1], unit = null;

      if(value.parseColor('#zzzzzz') != '#zzzzzz') {
        value = value.parseColor();
        unit  = 'color';
      } else if(property == 'opacity') {
        value = parseFloat(value);
        if(/MSIE/.test(navigator.userAgent) && !window.opera && (!this.element.currentStyle.hasLayout))
          this.element.setStyle({zoom: 1});
      } else if(Element.CSS_LENGTH.test(value)) 
        var components = value.match(/^([\+\-]?[0-9\.]+)(.*)$/),
          value = parseFloat(components[1]), unit = (components.length == 3) ? components[2] : null;

      var originalValue = this.element.getStyle(property);
      return $H({ 
        style: property, 
        originalValue: unit=='color' ? parseColor(originalValue) : parseFloat(originalValue || 0), 
        targetValue: unit=='color' ? parseColor(value) : value,
        unit: unit
      });
    }.bind(this)).reject(function(transform){
      return (
        (transform.originalValue == transform.targetValue) ||
        (
          transform.unit != 'color' &&
          (isNaN(transform.originalValue) || isNaN(transform.targetValue))
        )
      )
    });
  },
  update: function(position) {
    var style = $H(), value = null;
    this.transforms.each(function(transform){
      value = transform.unit=='color' ?
        $R(0,2).inject('#',function(m,v,i){
          return m+(Math.round(transform.originalValue[i]+
            (transform.targetValue[i] - transform.originalValue[i])*position)).toColorPart() }) : 
        transform.originalValue + Math.round(
          ((transform.targetValue - transform.originalValue) * position) * 1000)/1000 + transform.unit;
      style[transform.style] = value;
    });
    this.element.setStyle(style);
  }
});

Effect.Transform = Class.create();
Object.extend(Effect.Transform.prototype, {
  initialize: function(tracks){
    this.tracks  = [];
    this.options = arguments[1] || {};
    this.addTracks(tracks);
  },
  addTracks: function(tracks){
    tracks.each(function(track){
      var data = $H(track).values().first();
      this.tracks.push($H({
        ids:     $H(track).keys().first(),
        effect:  Effect.Morph,
        options: { style: data }
      }));
    }.bind(this));
    return this;
  },
  play: function(){
    return new Effect.Parallel(
      this.tracks.map(function(track){
        var elements = [$(track.ids) || $$(track.ids)].flatten();
        return elements.map(function(e){ return new track.effect(e, Object.extend({ sync:true }, track.options)) });
      }).flatten(),
      this.options
    );
  }
});

Element.CSS_PROPERTIES = $w(
  'backgroundColor backgroundPosition borderBottomColor borderBottomStyle ' + 
  'borderBottomWidth borderLeftColor borderLeftStyle borderLeftWidth ' +
  'borderRightColor borderRightStyle borderRightWidth borderSpacing ' +
  'borderTopColor borderTopStyle borderTopWidth bottom clip color ' +
  'fontSize fontWeight height left letterSpacing lineHeight ' +
  'marginBottom marginLeft marginRight marginTop markerOffset maxHeight '+
  'maxWidth minHeight minWidth opacity outlineColor outlineOffset ' +
  'outlineWidth paddingBottom paddingLeft paddingRight paddingTop ' +
  'right textIndent top width wordSpacing zIndex');
  
Element.CSS_LENGTH = /^(([\+\-]?[0-9\.]+)(em|ex|px|in|cm|mm|pt|pc|\%))|0$/;

String.prototype.parseStyle = function(){
  var element = Element.extend(document.createElement('div'));
  element.innerHTML = '<div style="' + this + '"></div>';
  var style = element.down().style, styleRules = $H();
  
  Element.CSS_PROPERTIES.each(function(property){
    if(style[property]) styleRules[property] = style[property]; 
  });
  if(/MSIE/.test(navigator.userAgent) && !window.opera && this.indexOf('opacity') > -1) {
    styleRules.opacity = this.match(/opacity:\s*((?:0|1)?(?:\.\d*)?)/)[1];
  }
  return styleRules;
};

Element.morph = function(element, style) {
  new Effect.Morph(element, Object.extend({ style: style }, arguments[2] || {}));
  return element;
};

['setOpacity','getOpacity','getInlineOpacity','forceRerendering','setContentZoom',
 'collectTextNodes','collectTextNodesIgnoreClass','morph'].each( 
  function(f) { Element.Methods[f] = Element[f]; }
);

Element.Methods.visualEffect = function(element, effect, options) {
  s = effect.gsub(/_/, '-').camelize();
  effect_class = s.charAt(0).toUpperCase() + s.substring(1);
  new Effect[effect_class](element, options);
  return $(element);
};

Element.addMethods();

// script.aculo.us slider.js v1.7.0, Fri Jan 19 19:16:36 CET 2007

// Copyright (c) 2005, 2006 Marty Haught, Thomas Fuchs 
//
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/

if(!Control) var Control = {};
Control.Slider = Class.create();


// options:
//  axis: 'vertical', or 'horizontal' (default)
//
// callbacks:
//  onChange(value)
//  onSlide(value)
Control.Slider.prototype = {
  initialize: function(handle, track, options) {
  	var slider = this;
    
    if(handle instanceof Array) {
      this.handles = handle.collect( function(e) { return $(e) });
    } else {
      this.handles = [$(handle)];
    }
    
    this.track   = $(track);
    this.options = options || {};

    this.axis      = this.options.axis || 'horizontal';
    this.increment = this.options.increment || 1;
    this.step      = parseInt(this.options.step || '1');
    this.range     = this.options.range || $R(0,1);
    
    this.value     = 0; // assure backwards compat
    this.values    = this.handles.map( function() { return 0 });
    this.spans     = this.options.spans ? this.options.spans.map(function(s){ return $(s) }) : false;
    this.options.startSpan = $(this.options.startSpan || null);
    this.options.endSpan   = $(this.options.endSpan || null);

    this.restricted = this.options.restricted || false;

    this.maximum   = this.options.maximum || this.range.end;
    this.minimum   = this.options.minimum || this.range.start;

    // Will be used to align the handle onto the track, if necessary
    this.alignX = parseInt(this.options.alignX || '0');
    this.alignY = parseInt(this.options.alignY || '0');
    
    this.trackLength = this.maximumOffset() - this.minimumOffset();

    this.handleLength = this.isVertical() ? 
      (this.handles[0].offsetHeight != 0 ? 
        this.handles[0].offsetHeight : this.handles[0].style.height.replace(/px$/,"")) : 
      (this.handles[0].offsetWidth != 0 ? this.handles[0].offsetWidth : 
        this.handles[0].style.width.replace(/px$/,""));

    this.active   = false;
    this.dragging = false;
    this.disabled = false;

    if(this.options.disabled) this.setDisabled();

    // Allowed values array
    this.allowedValues = this.options.values ? this.options.values.sortBy(Prototype.K) : false;
    if(this.allowedValues) {
      this.minimum = this.allowedValues.min();
      this.maximum = this.allowedValues.max();
    }

    this.eventMouseDown = this.startDrag.bindAsEventListener(this);
    this.eventMouseUp   = this.endDrag.bindAsEventListener(this);
    this.eventMouseMove = this.update.bindAsEventListener(this);

    // Initialize handles in reverse (make sure first handle is active)
    this.handles.each( function(h,i) {
      i = slider.handles.length-1-i;
      slider.setValue(parseFloat(
        (slider.options.sliderValue instanceof Array ? 
          slider.options.sliderValue[i] : slider.options.sliderValue) || 
         slider.range.start), i);
      Element.makePositioned(h); // fix IE
      Event.observe(h, "mousedown", slider.eventMouseDown);
    });
    
    Event.observe(this.track, "mousedown", this.eventMouseDown);
    Event.observe(document, "mouseup", this.eventMouseUp);
    Event.observe(document, "mousemove", this.eventMouseMove);
    
    this.initialized = true;
  },
  dispose: function() {
    var slider = this;    
    Event.stopObserving(this.track, "mousedown", this.eventMouseDown);
    Event.stopObserving(document, "mouseup", this.eventMouseUp);
    Event.stopObserving(document, "mousemove", this.eventMouseMove);
    this.handles.each( function(h) {
      Event.stopObserving(h, "mousedown", slider.eventMouseDown);
    });
  },
  setDisabled: function(){
    this.disabled = true;
  },
  setEnabled: function(){
    this.disabled = false;
  },  
  getNearestValue: function(value){
    if(this.allowedValues){
      if(value >= this.allowedValues.max()) return(this.allowedValues.max());
      if(value <= this.allowedValues.min()) return(this.allowedValues.min());
      
      var offset = Math.abs(this.allowedValues[0] - value);
      var newValue = this.allowedValues[0];
      this.allowedValues.each( function(v) {
        var currentOffset = Math.abs(v - value);
        if(currentOffset <= offset){
          newValue = v;
          offset = currentOffset;
        } 
      });
      return newValue;
    }
    if(value > this.range.end) return this.range.end;
    if(value < this.range.start) return this.range.start;
    return value;
  },
  setValue: function(sliderValue, handleIdx){
    if(!this.active) {
      this.activeHandleIdx = handleIdx || 0;
      this.activeHandle    = this.handles[this.activeHandleIdx];
      this.updateStyles();
    }
    handleIdx = handleIdx || this.activeHandleIdx || 0;
    if(this.initialized && this.restricted) {
      if((handleIdx>0) && (sliderValue<this.values[handleIdx-1]))
        sliderValue = this.values[handleIdx-1];
      if((handleIdx < (this.handles.length-1)) && (sliderValue>this.values[handleIdx+1]))
        sliderValue = this.values[handleIdx+1];
    }
    sliderValue = this.getNearestValue(sliderValue);
    this.values[handleIdx] = sliderValue;
    this.value = this.values[0]; // assure backwards compat
    
    this.handles[handleIdx].style[this.isVertical() ? 'top' : 'left'] = 
      this.translateToPx(sliderValue);
    
    this.drawSpans();
    if(!this.dragging || !this.event) this.updateFinished();
  },
  setValueBy: function(delta, handleIdx) {
    this.setValue(this.values[handleIdx || this.activeHandleIdx || 0] + delta, 
      handleIdx || this.activeHandleIdx || 0);
  },
  translateToPx: function(value) {
    return Math.round(
      ((this.trackLength-this.handleLength)/(this.range.end-this.range.start)) * 
      (value - this.range.start)) + "px";
  },
  translateToValue: function(offset) {
    return ((offset/(this.trackLength-this.handleLength) * 
      (this.range.end-this.range.start)) + this.range.start);
  },
  getRange: function(range) {
    var v = this.values.sortBy(Prototype.K); 
    range = range || 0;
    return $R(v[range],v[range+1]);
  },
  minimumOffset: function(){
    return(this.isVertical() ? this.alignY : this.alignX);
  },
  maximumOffset: function(){
    return(this.isVertical() ? 
      (this.track.offsetHeight != 0 ? this.track.offsetHeight :
        this.track.style.height.replace(/px$/,"")) - this.alignY : 
      (this.track.offsetWidth != 0 ? this.track.offsetWidth : 
        this.track.style.width.replace(/px$/,"")) - this.alignY);
  },  
  isVertical:  function(){
    return (this.axis == 'vertical');
  },
  drawSpans: function() {
    var slider = this;
    if(this.spans)
      $R(0, this.spans.length-1).each(function(r) { slider.setSpan(slider.spans[r], slider.getRange(r)) });
    if(this.options.startSpan)
      this.setSpan(this.options.startSpan,
        $R(0, this.values.length>1 ? this.getRange(0).min() : this.value ));
    if(this.options.endSpan)
      this.setSpan(this.options.endSpan, 
        $R(this.values.length>1 ? this.getRange(this.spans.length-1).max() : this.value, this.maximum));
  },
  setSpan: function(span, range) {
    if(this.isVertical()) {
      span.style.top = this.translateToPx(range.start);
      span.style.height = this.translateToPx(range.end - range.start + this.range.start);
    } else {
      span.style.left = this.translateToPx(range.start);
      span.style.width = this.translateToPx(range.end - range.start + this.range.start);
    }
  },
  updateStyles: function() {
    this.handles.each( function(h){ Element.removeClassName(h, 'selected') });
    Element.addClassName(this.activeHandle, 'selected');
  },
  startDrag: function(event) {
    if(Event.isLeftClick(event)) {
      if(!this.disabled){
        this.active = true;
        
        var handle = Event.element(event);
        var pointer  = [Event.pointerX(event), Event.pointerY(event)];
        var track = handle;
        if(track==this.track) {
          var offsets  = Position.cumulativeOffset(this.track); 
          this.event = event;
          this.setValue(this.translateToValue( 
           (this.isVertical() ? pointer[1]-offsets[1] : pointer[0]-offsets[0])-(this.handleLength/2)
          ));
          var offsets  = Position.cumulativeOffset(this.activeHandle);
          this.offsetX = (pointer[0] - offsets[0]);
          this.offsetY = (pointer[1] - offsets[1]);
        } else {
          // find the handle (prevents issues with Safari)
          while((this.handles.indexOf(handle) == -1) && handle.parentNode) 
            handle = handle.parentNode;
            
          if(this.handles.indexOf(handle)!=-1) {
            this.activeHandle    = handle;
            this.activeHandleIdx = this.handles.indexOf(this.activeHandle);
            this.updateStyles();
            
            var offsets  = Position.cumulativeOffset(this.activeHandle);
            this.offsetX = (pointer[0] - offsets[0]);
            this.offsetY = (pointer[1] - offsets[1]);
          }
        }
      }
      Event.stop(event);
    }
  },
  update: function(event) {
   if(this.active) {
      if(!this.dragging) this.dragging = true;
      this.draw(event);
      // fix AppleWebKit rendering
      if(navigator.appVersion.indexOf('AppleWebKit')>0) window.scrollBy(0,0);
      Event.stop(event);
   }
  },
  draw: function(event) {
    var pointer = [Event.pointerX(event), Event.pointerY(event)];
    var offsets = Position.cumulativeOffset(this.track);
    pointer[0] -= this.offsetX + offsets[0];
    pointer[1] -= this.offsetY + offsets[1];
    this.event = event;
    this.setValue(this.translateToValue( this.isVertical() ? pointer[1] : pointer[0] ));
    if(this.initialized && this.options.onSlide)
      this.options.onSlide(this.values.length>1 ? this.values : this.value, this);
  },
  endDrag: function(event) {
    if(this.active && this.dragging) {
      this.finishDrag(event, true);
      Event.stop(event);
    }
    this.active = false;
    this.dragging = false;
  },  
  finishDrag: function(event, success) {
    this.active = false;
    this.dragging = false;
    this.updateFinished();
  },
  updateFinished: function() {
    if(this.initialized && this.options.onChange) 
      this.options.onChange(this.values.length>1 ? this.values : this.value, this);
    this.event = null;
  }
}


function HSVobject (hue, saturation, value) {
	// Object definition.
	this.h = hue; this.s = saturation; this.v = value;
	this.validate = function () {
		if (this.h <= 0) {this.h = 0;}
		if (this.s <= 0) {this.s = 0;}
		if (this.v <= 0) {this.v = 0;}
		if (this.h > 360) {this.h = 360;}
		if (this.s > 100) {this.s = 100;}
		if (this.v > 100) {this.v = 100;}
	};
}

function RGBobject (red, green, blue) {
	// Object definition.
	this.r = red; this.g = green; this.b = blue;
	this.validate = function () {
		if (this.r <= 0) {this.r = 0;}
		if (this.g <= 0) {this.g = 0;}
		if (this.b <= 0) {this.b = 0;}
		if (this.r > 255) {this.r = 255;}
		if (this.g > 255) {this.g = 255;}
		if (this.b > 255) {this.b = 255;}
	};
}

function hexify(number) {
	var digits = '0123456789ABCDEF';
	var lsd = number % 16;
	var msd = (number - lsd) / 16;
	var hexified = digits.charAt(msd) + digits.charAt(lsd);
	return hexified;
}

function RGB2hex (RGB) {
	return "#" + hexify(RGB.r) + hexify(RGB.g) + hexify(RGB.b);
}

function hsvChange (new_value,id) {
	var RGB = new RGBobject(0, 0, 0);
	var HSV = new HSVobject(new_value, 100, 100);
	HSV.validate();
	HSV2RGB (HSV, RGB);
	$(id).style.backgroundColor = RGB2hex(RGB);
}

function HSV2RGB (HSV, RGB) {
	var s = HSV.s / 100; var v = HSV.v / 100;
	if (s == 0) {
		RGB.r = v * 255;
		RGB.g = v * 255;
		RGB.v = v * 255;
	} else {
		var_h = (HSV.h / 60) % 6;
		var_i = Math.floor(var_h);
		var_1 = v * (1 - s);
		var_2 = v * (1 - s * (var_h - var_i));
		var_3 = v * (1 - s * (1 - (var_h - var_i)));
		
		if (var_i == 0) {var_r = v; var_g = var_3; var_b = var_1}
		else if (var_i == 1) {var_r = var_2; var_g = v; var_b = var_1}
		else if (var_i == 2) {var_r = var_1; var_g = v; var_b = var_3}
		else if (var_i == 3) {var_r = var_1; var_g = var_2; var_b = v}
		else if (var_i == 4) {var_r = var_3; var_g = var_1; var_b = v}
		else {var_r = v; var_g = var_1; var_b = var_2};
		
		RGB.r = var_r * 255;
		RGB.g = var_g * 255;
		RGB.b = var_b * 255;
	}
}

/* X Library, Copyright 2001-2005 Michael Foster (Cross-Browser.com). Distributed under the terms of the GNU LGPL */
/* floater_xlib.js compiled with XC v0.22b, see floater_xlib.txt for contributor copyrights, license info and documentation */
var xVersion='4.0',xOp7Up,xOp6Dn,xIE4Up,xIE4,xIE5,xNN4,xUA=navigator.userAgent.toLowerCase();if(window.opera){var i=xUA.indexOf('opera');if(i!=-1){var v=parseInt(xUA.charAt(i+6));xOp7Up=v>=7;xOp6Dn=v<7;}}else if(navigator.vendor!='KDE' && document.all && xUA.indexOf('msie')!=-1){xIE4Up=parseFloat(navigator.appVersion)>=4;xIE4=xUA.indexOf('msie 4')!=-1;xIE5=xUA.indexOf('msie 5')!=-1;}else if(document.layers){xNN4=true;}xMac=xUA.indexOf('mac')!=-1;
function xGetComputedStyle(oEle, sProp, bInt){var s, p = 'undefined';var dv = document.defaultView;if(dv && dv.getComputedStyle){s = dv.getComputedStyle(oEle,'');if (s) p = s.getPropertyValue(sProp);}else if(oEle.currentStyle) {var a = sProp.split('-');sProp = a[0];for (var i=1; i<a.length; ++i) {c = a[i].charAt(0);sProp += a[i].replace(c, c.toUpperCase());}   p = oEle.currentStyle[sProp];}else return null;return bInt ? (parseInt(p) || 0) : p;}
function xDef(){for(var i=0; i<arguments.length; ++i){if(typeof(arguments[i])=='undefined') return false;}return true;}
function xNum(){for(var i=0; i<arguments.length; ++i){if(isNaN(arguments[i]) || typeof(arguments[i])!='number') return false;}return true;}
function xStr(s){for(var i=0; i<arguments.length; ++i){if(typeof(arguments[i])!='string') return false;}return true;}
function xGetElementById(e){if(typeof(e)!='string') return e;if(document.getElementById) e=document.getElementById(e);else if(document.all) e=document.all[e];else e=null;return e;}
function xPageX(e){if (!(e=xGetElementById(e))) return 0;var x = 0;while (e) {if (xDef(e.offsetLeft)) x += e.offsetLeft;e = xDef(e.offsetParent) ? e.offsetParent : null;}return x;}
function xPageY(e){if (!(e=xGetElementById(e))) return 0;var y = 0;while (e) {if (xDef(e.offsetTop)) y += e.offsetTop;e = xDef(e.offsetParent) ? e.offsetParent : null;}return y;}
function xClientHeight(){var h=0;if(xOp6Dn||xUA.indexOf('safari')!=-1) h=window.innerHeight;else if(document.compatMode == 'CSS1Compat' && !window.opera && document.documentElement && document.documentElement.clientHeight)h=document.documentElement.clientHeight;else if(document.body && document.body.clientHeight)h=document.body.clientHeight;else if(xDef(window.innerWidth,window.innerHeight,document.width)) {h=window.innerHeight;if(document.width>window.innerWidth) h-=16;}return h;}
function xClientWidth(){var w=0;if(xOp6Dn) w=window.innerWidth;else if(document.compatMode == 'CSS1Compat' && !window.opera && document.documentElement && document.documentElement.clientWidth)w=document.documentElement.clientWidth;else if(document.body && document.body.clientWidth)w=document.body.clientWidth;else if(xDef(window.innerWidth,window.innerHeight,document.height)) {w=window.innerWidth;if(document.height>window.innerHeight) w-=16;}return w;}
function xTop(e, iY){if(!(e=xGetElementById(e))) return 0;var css=xDef(e.style);if(css && xStr(e.style.top)) {if(xNum(iY)) e.style.top=iY+'px';else {iY=parseInt(e.style.top);if(isNaN(iY)) iY=0;}}else if(css && xDef(e.style.pixelTop)) {if(xNum(iY)) e.style.pixelTop=iY;else iY=e.style.pixelTop;}return iY;}
function xLeft(e, iX){if(!(e=xGetElementById(e))) return 0;var css=xDef(e.style);if (css && xStr(e.style.left)) {if(xNum(iX)) e.style.left=iX+'px';else {iX=parseInt(e.style.left);if(isNaN(iX)) iX=0;}}else if(css && xDef(e.style.pixelLeft)) {if(xNum(iX)) e.style.pixelLeft=iX;else iX=e.style.pixelLeft;}return iX;}
function xHeight(e,h){if(!(e=xGetElementById(e))) return 0;if (xNum(h)) {if (h<0) h = 0;else h=Math.round(h);}else h=-1;var css=xDef(e.style);if (e == document || e.tagName.toLowerCase() == 'html' || e.tagName.toLowerCase() == 'body') {h = xClientHeight();}else if(css && xDef(e.offsetHeight) && xStr(e.style.height)) {if(h>=0) {var pt=0,pb=0,bt=0,bb=0;if (document.compatMode=='CSS1Compat') {var gcs = xGetComputedStyle;pt=gcs(e,'padding-top',1);if (pt !== null) {pb=gcs(e,'padding-bottom',1);bt=gcs(e,'border-top-width',1);bb=gcs(e,'border-bottom-width',1);}else if(xDef(e.offsetHeight,e.style.height)){e.style.height=h+'px';pt=e.offsetHeight-h;}}h-=(pt+pb+bt+bb);if(isNaN(h)||h<0) return;else e.style.height=h+'px';}h=e.offsetHeight;}else if(css && xDef(e.style.pixelHeight)) {if(h>=0) e.style.pixelHeight=h;h=e.style.pixelHeight;}return h;}
function xWidth(e,w){if(!(e=xGetElementById(e))) return 0;if (xNum(w)) {if (w<0) w = 0;else w=Math.round(w);}else w=-1;var css=xDef(e.style);if (e == document || e.tagName.toLowerCase() == 'html' || e.tagName.toLowerCase() == 'body') {w = xClientWidth();}else if(css && xDef(e.offsetWidth) && xStr(e.style.width)) {if(w>=0) {var pl=0,pr=0,bl=0,br=0;if (document.compatMode=='CSS1Compat') {var gcs = xGetComputedStyle;pl=gcs(e,'padding-left',1);if (pl !== null) {pr=gcs(e,'padding-right',1);bl=gcs(e,'border-left-width',1);br=gcs(e,'border-right-width',1);}else if(xDef(e.offsetWidth,e.style.width)){e.style.width=w+'px';pl=e.offsetWidth-w;}}w-=(pl+pr+bl+br);if(isNaN(w)||w<0) return;else e.style.width=w+'px';}w=e.offsetWidth;}else if(css && xDef(e.style.pixelWidth)) {if(w>=0) e.style.pixelWidth=w;w=e.style.pixelWidth;}return w;}
function xScrollLeft(e, bWin){var offset=0;if (!xDef(e) || bWin || e == document || e.tagName.toLowerCase() == 'html' || e.tagName.toLowerCase() == 'body') {var w = window;if (bWin && e) w = e;if(w.document.documentElement && w.document.documentElement.scrollLeft) offset=w.document.documentElement.scrollLeft;else if(w.document.body && xDef(w.document.body.scrollLeft)) offset=w.document.body.scrollLeft;}else {e = xGetElementById(e);if (e && xNum(e.scrollLeft)) offset = e.scrollLeft;}return offset;}
function xScrollTop(e, bWin){var offset=0;if (!xDef(e) || bWin || e == document || e.tagName.toLowerCase() == 'html' || e.tagName.toLowerCase() == 'body') {var w = window;if (bWin && e) w = e;if(w.document.documentElement && w.document.documentElement.scrollTop) offset=w.document.documentElement.scrollTop;else if(w.document.body && xDef(w.document.body.scrollTop)) offset=w.document.body.scrollTop;}else {e = xGetElementById(e);if (e && xNum(e.scrollTop)) offset = e.scrollTop;}return offset;}


function get_html_translation_table (table, quote_style) {
    // http://kevin.vanzonneveld.net
    // +   original by: Philip Peterson
    // +    revised by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +   bugfixed by: noname
    // +   bugfixed by: Alex
    // +   bugfixed by: Marco
    // +   bugfixed by: madipta
    // +   improved by: KELAN
    // +   improved by: Brett Zamir (http://brett-zamir.me)
    // +   bugfixed by: Brett Zamir (http://brett-zamir.me)
    // +      input by: Frank Forte
    // +   bugfixed by: T.Wild
    // +      input by: Ratheous
    // %          note: It has been decided that we're not going to add global
    // %          note: dependencies to php.js, meaning the constants are not
    // %          note: real constants, but strings instead. Integers are also supported if someone
    // %          note: chooses to create the constants themselves.
    // *     example 1: get_html_translation_table('HTML_SPECIALCHARS');
    // *     returns 1: {'"': '&quot;', '&': '&amp;', '<': '&lt;', '>': '&gt;'}
    
    var entities = {}, hash_map = {}, decimal = 0, symbol = '';
    var constMappingTable = {}, constMappingQuoteStyle = {};
    var useTable = {}, useQuoteStyle = {};
    
    // Translate arguments
    constMappingTable[0]      = 'HTML_SPECIALCHARS';
    constMappingTable[1]      = 'HTML_ENTITIES';
    constMappingQuoteStyle[0] = 'ENT_NOQUOTES';
    constMappingQuoteStyle[2] = 'ENT_COMPAT';
    constMappingQuoteStyle[3] = 'ENT_QUOTES';
 
    useTable       = !isNaN(table) ? constMappingTable[table] : table ? table.toUpperCase() : 'HTML_SPECIALCHARS';
    useQuoteStyle = !isNaN(quote_style) ? constMappingQuoteStyle[quote_style] : quote_style ? quote_style.toUpperCase() : 'ENT_COMPAT';
 
    if (useTable !== 'HTML_SPECIALCHARS' && useTable !== 'HTML_ENTITIES') {
        throw new Error("Table: "+useTable+' not supported');
        // return false;
    }
 
    entities['38'] = '&amp;';
    if (useTable === 'HTML_ENTITIES') {
        entities['160'] = '&nbsp;';
        entities['161'] = '&iexcl;';
        entities['162'] = '&cent;';
        entities['163'] = '&pound;';
        entities['164'] = '&curren;';
        entities['165'] = '&yen;';
        entities['166'] = '&brvbar;';
        entities['167'] = '&sect;';
        entities['168'] = '&uml;';
        entities['169'] = '&copy;';
        entities['170'] = '&ordf;';
        entities['171'] = '&laquo;';
        entities['172'] = '&not;';
        entities['173'] = '&shy;';
        entities['174'] = '&reg;';
        entities['175'] = '&macr;';
        entities['176'] = '&deg;';
        entities['177'] = '&plusmn;';
        entities['178'] = '&sup2;';
        entities['179'] = '&sup3;';
        entities['180'] = '&acute;';
        entities['181'] = '&micro;';
        entities['182'] = '&para;';
        entities['183'] = '&middot;';
        entities['184'] = '&cedil;';
        entities['185'] = '&sup1;';
        entities['186'] = '&ordm;';
        entities['187'] = '&raquo;';
        entities['188'] = '&frac14;';
        entities['189'] = '&frac12;';
        entities['190'] = '&frac34;';
        entities['191'] = '&iquest;';
        entities['192'] = '&Agrave;';
        entities['193'] = '&Aacute;';
        entities['194'] = '&Acirc;';
        entities['195'] = '&Atilde;';
        entities['196'] = '&Auml;';
        entities['197'] = '&Aring;';
        entities['198'] = '&AElig;';
        entities['199'] = '&Ccedil;';
        entities['200'] = '&Egrave;';
        entities['201'] = '&Eacute;';
        entities['202'] = '&Ecirc;';
        entities['203'] = '&Euml;';
        entities['204'] = '&Igrave;';
        entities['205'] = '&Iacute;';
        entities['206'] = '&Icirc;';
        entities['207'] = '&Iuml;';
        entities['208'] = '&ETH;';
        entities['209'] = '&Ntilde;';
        entities['210'] = '&Ograve;';
        entities['211'] = '&Oacute;';
        entities['212'] = '&Ocirc;';
        entities['213'] = '&Otilde;';
        entities['214'] = '&Ouml;';
        entities['215'] = '&times;';
        entities['216'] = '&Oslash;';
        entities['217'] = '&Ugrave;';
        entities['218'] = '&Uacute;';
        entities['219'] = '&Ucirc;';
        entities['220'] = '&Uuml;';
        entities['221'] = '&Yacute;';
        entities['222'] = '&THORN;';
        entities['223'] = '&szlig;';
        entities['224'] = '&agrave;';
        entities['225'] = '&aacute;';
        entities['226'] = '&acirc;';
        entities['227'] = '&atilde;';
        entities['228'] = '&auml;';
        entities['229'] = '&aring;';
        entities['230'] = '&aelig;';
        entities['231'] = '&ccedil;';
        entities['232'] = '&egrave;';
        entities['233'] = '&eacute;';
        entities['234'] = '&ecirc;';
        entities['235'] = '&euml;';
        entities['236'] = '&igrave;';
        entities['237'] = '&iacute;';
        entities['238'] = '&icirc;';
        entities['239'] = '&iuml;';
        entities['240'] = '&eth;';
        entities['241'] = '&ntilde;';
        entities['242'] = '&ograve;';
        entities['243'] = '&oacute;';
        entities['244'] = '&ocirc;';
        entities['245'] = '&otilde;';
        entities['246'] = '&ouml;';
        entities['247'] = '&divide;';
        entities['248'] = '&oslash;';
        entities['249'] = '&ugrave;';
        entities['250'] = '&uacute;';
        entities['251'] = '&ucirc;';
        entities['252'] = '&uuml;';
        entities['253'] = '&yacute;';
        entities['254'] = '&thorn;';
        entities['255'] = '&yuml;';
    }
 
    if (useQuoteStyle !== 'ENT_NOQUOTES') {
        entities['34'] = '&quot;';
    }
    if (useQuoteStyle === 'ENT_QUOTES') {
        entities['39'] = '&#39;';
    }
    entities['60'] = '&lt;';
    entities['62'] = '&gt;';
 
 
    // ascii decimals to real symbols
    for (decimal in entities) {
        symbol = String.fromCharCode(decimal);
        hash_map[symbol] = entities[decimal];
    }
    
    return hash_map;
}


function html_entity_decode (string, quote_style) {
    // http://kevin.vanzonneveld.net
    // +   original by: john (http://www.jd-tech.net)
    // +      input by: ger
    // +   improved by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +    revised by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +   bugfixed by: Onno Marsman
    // +   improved by: marc andreu
    // +    revised by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +    bugfixed by: Brett Zamir (http://brett-zamir.me)
    // +      input by: Ratheous
    // -    depends on: get_html_translation_table
    // *     example 1: html_entity_decode('Kevin &amp; van Zonneveld');
    // *     returns 1: 'Kevin & van Zonneveld'
    // *     example 2: html_entity_decode('&amp;lt;');
    // *     returns 2: '&lt;'
 
    var hash_map = {}, symbol = '', tmp_str = '', entity = '';
    tmp_str = string.toString();
    
    if (false === (hash_map = this.get_html_translation_table('HTML_ENTITIES', quote_style))) {
        return false;
    }
 
    for (symbol in hash_map) {
        entity = hash_map[symbol];
        tmp_str = tmp_str.split(entity).join(symbol);
    }
    tmp_str = tmp_str.split('&#039;').join("'");
    
    return tmp_str;
}

function htmlspecialchars (string, quote_style) {
    // http://kevin.vanzonneveld.net
    // +   original by: Mirek Slugen
    // +   improved by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +   bugfixed by: Nathan
    // +   bugfixed by: Arno
    // +    revised by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +    bugfixed by: Brett Zamir (http://brett-zamir.me)
    // +      input by: Ratheous
    // -    depends on: get_html_translation_table
    // *     example 1: htmlspecialchars("<a href='test'>Test</a>", 'ENT_QUOTES');
    // *     returns 1: '&lt;a href=&#039;test&#039;&gt;Test&lt;/a&gt;'
 
    var hash_map = {}, symbol = '', tmp_str = '', entity = '';
    tmp_str = string.toString();
    
    if (false === (hash_map = this.get_html_translation_table('HTML_SPECIALCHARS', quote_style))) {
        return false;
    }
    
    hash_map["'"] = '&#039;';
    for (symbol in hash_map) {
        entity = hash_map[symbol];
        tmp_str = tmp_str.split(symbol).join(entity);
    }
    
    return tmp_str;
}

function htmlentities (string, quote_style) {
    // http://kevin.vanzonneveld.net
    // +   original by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +    revised by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +   improved by: nobbler
    // +    tweaked by: Jack
    // +   bugfixed by: Onno Marsman
    // +    revised by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +    bugfixed by: Brett Zamir (http://brett-zamir.me)
    // +      input by: Ratheous
    // -    depends on: get_html_translation_table
    // *     example 1: htmlentities('Kevin & van Zonneveld');
    // *     returns 1: 'Kevin &amp; van Zonneveld'
    // *     example 2: htmlentities("foo'bar","ENT_QUOTES");
    // *     returns 2: 'foo&#039;bar'
 
    var hash_map = {}, symbol = '', tmp_str = '', entity = '';
    tmp_str = string.toString();
    
    if (false === (hash_map = this.get_html_translation_table('HTML_ENTITIES', quote_style))) {
        return false;
    }
    hash_map["'"] = '&#039;';
    for (symbol in hash_map) {
        entity = hash_map[symbol];
        tmp_str = tmp_str.split(symbol).join(entity);
    }
    
    return tmp_str;
}


/*
* touchtunes.js
*
* Copyright (C) 1997-2008 by TouchTunes Digital Jukebox, Inc.
* All Rights Reserved.
*
* Disclosure or use in part or in whole without prior written consent
* constitutes an infringement of copyright, punishable by law.
*/
var d,dom,ie,ie4,ie5x,moz,mac,win,lin,old,ie5mac,ie5xwin,op;
d=document;n=navigator;na=n.appVersion;nua=n.userAgent;win=(na.indexOf('Win')!=-1);mac=(na.indexOf('Mac')!=-1);lin=(nua.indexOf('Linux')!=-1);
if(!d.layers){dom=(d.getElementById);op=(nua.indexOf('Opera')!=-1);konq=(nua.indexOf('Konqueror')!=-1);saf=(nua.indexOf('Safari')!=-1);moz=(nua.indexOf('Gecko')!=-1 && !saf && !konq);ie=(d.all && !op);ie4=(ie && !dom);ie5x=(d.all && dom);ie5mac=(mac && ie5x);ie5xwin=(win && ie5x);}
var detect=navigator.userAgent.toLowerCase();var OS,browser,version,thestring;
if(checkIt('konqueror')){browser="Konqueror";OS="Linux";}else if(checkIt('safari')){browser="Safari";}else if(checkIt('omniweb')){browser="OmniWeb";}else if(checkIt('opera')){browser="Opera";}else if(checkIt('webtv')){browser="WebTV";}else if(checkIt('icab')){browser="iCab";}else if(checkIt('msie')){browser="IE";}else if(checkIt('firefox')){browser="Firefox";}else if(checkIt('netscape')){browser="Netscape";}else if(checkIt('gecko')){browser="Gecko";}else if(!checkIt('compatible')){browser="Netscape";version=detect.charAt(8);}else{browser="unknown";}
if(!version){version='';c=detect.charAt(place+thestring.length);var i=0;var firstDot=false;while(isDigit(c) && place+thestring.length+i<detect.length){i++;if(c=='.' && !firstDot){firstDot=true;}else if(c=='.'){c=detect.charAt(place+thestring.length+i);continue;}version=version+c;c=detect.charAt(place+thestring.length+i);}}
if(!OS){if(checkIt('linux')){OS="Linux";}else if(checkIt('x11')){OS="Unix";}else if(checkIt('mac')){OS="Mac";}else if(checkIt('win')){OS="Windows";}else{OS="unknown";}}
function isDigit(num){if(num.length>1){return false;}var string="1234567890.";if(string.indexOf(num)!=-1){return true;}return false;}
function checkIt(string){place=detect.indexOf(string)+1;thestring=string;return place;}

function isBrowserSupported(){if(browser=='IE' && version>=7)return true;if(browser=='Firefox' && version>=2 && version<20000000)return true;if(browser=='Safari')return true;if(browser=='Opera' && (version<9 || version>20000000))return false;if(browser=='Opera')return true;if(detect.indexOf('googlebot')!=-1)return true;return false;}

var winW=800;if(typeof(window.innerWidth)=='number'){winW=window.innerWidth;}else if(document.documentElement && document.documentElement.clientWidth){winW=document.documentElement.clientWidth;}else if(document.body && document.body.clientWidth){winW=document.body.clientWidth;}
var winH=800;if(typeof(window.innerHeight)=='number'){winH=window.innerHeight;}else if(document.documentElement && document.documentElement.clientHeight){winH=document.documentElement.clientHeight;}else if(document.body && document.body.clientHeight){winH=document.body.clientHeight;}
var pointer='pointer';if(browser=='IE' && OS=='Windows')pointer='hand';
function popWindow(url){leftVal=(screen.width-600)/2;topVal=(screen.height-500)/2;win=window.open(url,'tt_db_pop','location=0,menubar=1,resizable=1,height=500,width=620,left='+leftVal+',top='+topVal);}
var going=false;function go(url){if(!going){showLoading();going=true;setTimeout('going=false',30000);window.location=url;}}
function formChar(form){if(form.action.indexOf('?')==-1){return '?';}else{return '&';}}

function setOpacity(obj,opacity){opacity=(opacity==100)?99.999:opacity;obj.style.filter="alpha(opacity:"+opacity+")";obj.style.KHTMLOpacity=opacity/100;obj.style.MozOpacity=opacity/100;obj.style.opacity=opacity/100;} 
function positionCenter(el,parentX,parentY, forceTop){
	if(typeof parentX=='undefined'){
		parentX=0;
	}
	if(typeof parentY=='undefined'){
		parentY=0;
	}
	if(typeof forceTop=='undefined'){
		forceTop=false;
	}
	var cH=xClientHeight();
	var cW=xClientWidth();
	var eH=xHeight($(el));
	var eW=xWidth($(el));
	var l=xScrollLeft()+(cW/2)-(eW/2)-parentX;
	if(l<xScrollLeft()-parentX){
		l=xScrollLeft()-parentX;
	}
	if(cW<eW){
		l=xScrollLeft()-parentX;
	}
	var t=xScrollTop()+(cH/2)-(eH/2)-parentY;
	if(t<xScrollTop()-parentY){
		t=xScrollTop()-parentY;
	}
	if(cH<eH){
		if(forceTop){
			t=parentY;}
		else{
			t=xScrollTop()-parentY;
		}
	}
	$(el).style.position='absolute';
	$(el).style.left=l+'px';
	$(el).style.top=t+'px';
}
function showLoadingBG(fade){var s=$("loadingBG").style;s.zIndex=98;s.width=xClientWidth()+"px";if(xClientHeight()>xPageY("bottomOfPage")+15){s.height=xClientHeight()+"px";}else if(xPageY("bottomOfPage")+15<32768){s.height=(xPageY("bottomOfPage")+15)+"px";}else{s.height="32768px";}if(fade){Effect.Appear("loadingBG",{from:0,to:0.6});}else{setOpacity($("loadingBG"),60);Element.show("loadingBG");}}
function showLoading(fade){
    if (typeof(lookFor)=='undefined'){
        fade=false;
    }
	if(summaryReloadTimer){
		clearTimeout(summaryReloadTimer);
	}
	var s2=$("loading").style;
	hideCombos(true);
	showLoadingBG(fade);
	s2.zIndex=99;
	Element.show("loading");
	positionCenter("loading");
	if(ie5x)document.body.style.cursor='wait';
	if($('ttusbupdater')){
		Element.hide('ttusbupdater')
	}
}
function hideLoading(){Effect.Fade("loadingBG",{from:0.6,to:0});Element.hide("loading");if(ie5x)document.body.style.cursor='';showCombos();}
var hiddenCombos=new Array();function hideCombos(hide){if(browser=='IE' && OS=='Windows' && version<7){if(hide){var combos=document.getElementsByTagName('select');var real_combos=new Array();for(var i=0;i<combos.length;i++){if(!isAlreadyHidden(combos[i])){real_combos.push(combos[i]);}}combos=real_combos;hiddenCombos.push(combos);for(i=0;i<combos.length;i++){Element.hide(combos[i]);}}else{combos=hiddenCombos.pop();for(i=0;i<combos.length;i++){Element.show(combos[i]);combos[i].style.visibility='inherit';}}}}
function showCombos(){hideCombos(false);}
function isAlreadyHidden(combo){for(var i=0;i<hiddenCombos.length;i++){for(var j=0;j<hiddenCombos[i].length;j++){if(hiddenCombos[i][j]==combo){return true;}}}return false;}
var needToPositionScheduledSetting;
function showViewScheduling(positioned){
	showScheduledSettingMessage();
	hideLoadingScheduling();
	Element.show('ScheduledSetting');
	if(needToPositionScheduledSetting){
		positionCenter("ScheduledSetting",0,0,positioned);
		needToPositionScheduledSetting=false;
	}
	document.body.style.cursor='';
}
function showSetScheduling(){
	hideLoadingSchedulingSet();
	Element.show('ScheduledSettingSet');
	positionCenter("ScheduledSettingSet",xLeft('ScheduledSetting'),xTop('ScheduledSetting'));
	document.body.style.cursor='';
}
function showScheduledSettingMessage(el){var s=$("loadingBG2").style;var dims=Element.getDimensions("ScheduledSetting");s.height=dims["height"]+"px";s.width=dims["width"]+"px";if(el!=null){Element.hide("removing");Element.hide("loading2");Element.hide("removingAll");Element.hide("reloading");if(!Element.visible("loadingBG2")){Effect.Appear("loadingBG2",{from:0,to:0.6,duration:0.3});}Element.show(el);positionCenter(el);}document.body.style.cursor='wait';}
function showSavingScheduling(){hideCombos(true);var s=$("loadingBG3").style;var dims=Element.getDimensions($("ScheduledSettingSet"));s.height=dims["height"]+"px";s.width=dims["width"]+"px";if(!Element.visible("loadingBG3")){Effect.Appear("loadingBG3",{from:0,to:0.6,duration:0.3});}Element.show("saving");positionCenter("saving");document.body.style.cursor='wait';}
function hideLoadingScheduling(){if(Element.visible("loadingBG2")){Effect.Fade("loadingBG2",{from:0.6,to:0,duration:0.3});}Element.show('display_monthly');Element.show('display_monthlyButton');Element.show('display_daily');Element.hide("loading2");Element.hide("removing");Element.hide("removingAll");Element.hide("loading");Element.hide("reloading");$("loadingBG").style.zIndex=0;}
function hideLoadingSchedulingSet(){Element.hide("loading2");Element.hide("saving");}
function hideSavingScheduling(error){Element.hide("loadingBG3");$("loadingBG3").style.visibility='hidden';Element.hide("saving");document.body.style.cursor='';showCombos();}

var loadingJukebox=false;

function changeJukebox(form){if(!loadingJukebox){loadingJukebox=true;showLoading();form.buttonSelect.value='Select';form.action=form.action+formChar(form)+'ResetPage=1';form.submit();}}
function saveJukeDescription(form){form.buttonSelect.value='save';form.action=form.action+formChar(form)+'ResetPage=1';form.submit();}

function changeResultsPP(form){changeJukebox(form);}
var searching=false;function checkEnter(form){if(window.event && window.event.keyCode==13){if(!searching){searching=true;formSubmit();var input=form.buttonSearchIE;input.name='buttonSearch';input.value='Search';form.submit();}}}
function formSubmit(){if(ie5x)document.body.style.cursor='wait';}
var loggingOut=false;function logout(url){if(!loggingOut){showLoading();loggingOut=true;document.location.href=url;}}
function pulsate(elementId,numPulsations){Effect.Transitions.pulseMore=function(pos){var pos2=pos*2*numPulsations;var x=(Math.floor(pos2)%2==0?(pos2-Math.floor(pos2)):1-(pos2-Math.floor(pos2)));return x;};element=$(elementId);var options={};var oldOpacity=Element.getInlineOpacity(element);var transition=options.transition || Effect.Transitions.sinoidal;var reverser=function(pos){return transition(1-Effect.Transitions.pulseMore(pos))};reverser.bind(transition);new Effect.Opacity(element,Object.extend(Object.extend({duration:1.6*numPulsations,from:0,afterFinishInternal:function(effect){Element.setStyle(effect.element,{opacity: oldOpacity});}},options),{transition:reverser}));}
function findThisRow(keyId,inElement,lookFor){if(typeof(lookFor)=='undefined'){lookFor=null;}for(i=0;i<inElement.childNodes.length;i++){var child=inElement.childNodes[i];if(child.innerHTML&&(child.innerHTML.indexOf("explode('"+keyId+"'")!=-1||child.innerHTML.indexOf("explode_f('"+keyId+"'")!=-1)&&(lookFor == null || typeof(lookFor)=='undefined'||child.innerHTML.indexOf(lookFor)!=-1)){if(child.nodeName=='TR'){return child;}child=findThisRow(keyId,child,lookFor);if(child!=null){return child;}}}return null;}
function removeAllChildsOf(implodedRow){var type=implodedRow.className;if(type.indexOf(" even")!=-1){type=type.substr(0,type.indexOf(" even")-3);}else if(type.indexOf(" odd")!=-1){type=type.substr(0,type.indexOf(" odd")-3);}var table=implodedRow.parentNode;var goNow=false;for(i=0;i<table.childNodes.length;i++){var row=table.childNodes[i];if(row.nodeName=='TR' && row==implodedRow){goNow=true;}else if(row.nodeName=='TR' && goNow){if((type=='root' && (row.className.indexOf('artistRow')!=-1 || row.className.indexOf('albumRow')!=-1 || row.className.indexOf('songRow')!=-1)) || (type=='artist' && (row.className.indexOf('albumRow')!=-1 || row.className.indexOf('songRow')!=-1)) || (type=='album' && row.className.indexOf('songRow')!=-1)){Element.remove(row);i--;}if((type=='root' && row.className.indexOf('rootRow')!=-1) || (type=='album' && (row.className.indexOf('albumRow')!=-1 || row.className.indexOf('artistRow')!=-1 || row.className.indexOf('rootRow')!=-1)) || (type=='artist' && (row.className.indexOf('artistRow')!=-1 || row.className.indexOf('rootRow')!=-1))){break;}}}}
function emailCheck(emailStr){var emailPat=/^(.+)@(.+)$/;var specialChars="\\(\\)<>@,;:\\\\\\\"\\.\\[\\]";var validChars="\[^\\s" + specialChars + "\]";var quotedUser="(\"[^\"]*\")";var ipDomainPat=/^\[(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})\]$/;var atom=validChars + '+';var word="(" + atom + "|" + quotedUser + ")";var userPat=new RegExp("^" + word + "(\\." + word + ")*$");var domainPat=new RegExp("^" + atom + "(\\." + atom +")*$");var matchArray=emailStr.match(emailPat);if(matchArray==null){alert(errorMsg);return false;}var user=matchArray[1];var domain=matchArray[2];if(user.match(userPat)==null){alert(errorMsg);return false;}var IPArray=domain.match(ipDomainPat);if(IPArray!=null){for(var i=1;i<=4;i++){if(IPArray[i]>255){alert(errorMsg);return false;}}return true;}var domainArray=domain.match(domainPat);if(domainArray==null){alert(errorMsg);return false;}var atomPat=new RegExp(atom,"g");var domArr=domain.match(atomPat);var len=domArr.length;if((domArr[domArr.length-1]!="info") && (domArr[domArr.length-1]!="name") && (domArr[domArr.length-1]!="arpa") && (domArr[domArr.length-1]!="coop") && (domArr[domArr.length-1]!="aero")){if(domArr[domArr.length-1].length<2 || domArr[domArr.length-1].length>3){alert(errorMsg);return false;}}if(len<2){var errStr=errorMsg;alert(errStr);return false;}return true;}
function UPTvalidateform(thisform){if(emailCheck(thisform.email.value)){return true;}else{return false;}}
var printWindow;

var explodedKey;var lastExplode;var lastImplode;var currentMusicTree;var additionnalParameters;
function explode(keyId,imgNameExplode,encodedUid,page){var checkBoxStatus=false;var checkBoxName='';if(explodedKey!=null){alert(explodeKeyNotNulErrorMsg);return false;};explodedKey=keyId;for(i=0;i<document.forms[0].elements.length;i++){var element=document.forms[0].elements[i];if((element.name.indexOf('AlbumCheck_')!=-1||element.name.indexOf('ArtistCheck_')!=-1)&&element.value==keyId){checkBoxStatus=element.checked;checkBoxName=element.name;}}lastExplode=new Array(3);lastExplode[0]=keyId;lastExplode[1]=imgNameExplode;lastExplode[2]=encodedUid;lastExplode[3]=page;var explodedRow=findThisRow(keyId,$(currentMusicTree));var target=document.forms[0].action;if(target.indexOf("AdvancedSearch.jsp")!=-1||target.indexOf("Settings.jsp")!=-1||target.indexOf("DelMusic.jsp")!=-1){target=target.replace('.jsp','Ajax.jsp');}new Ajax.Request(target+randomize(document.forms[0]),{method:'post',postBody:imgNameExplode+'=1&resort=false&ajax=true&EncodedUid='+encodedUid+'&'+checkBoxName+'='+checkBoxStatus+additionnalParameters+'&d-'+encodedUid+'-p='+page+'&page='+page,onSuccess:done_exploding,onFailure:error_exploding});new Insertion.After(explodedRow,'<tr id="loading_row"><td>&nbsp;</td><td colspan="3" class="mainText3" style="padding-left: 50px">'+loadingMsg+'</td></tr>');return false;}
function error_exploding(response){if(response.status==12030 || response.status==12031){Element.remove("loading_row");explodedKey=null;explode(lastExplode[0],lastExplode[1],lastExplode[2],lastExplode[3]);}}
function done_exploding(originalRequest){Element.show("spanim_"+explodedKey);Element.hide("spanex_"+explodedKey);Element.hide("loading_row");new Insertion.Before("loading_row",originalRequest.responseText);Element.remove("loading_row");$("linkalb_"+explodedKey).onclick=$("imgim_"+explodedKey).onclick;explodedKey=null;}
function implode(keyId,imgNameImplode,encodedUid){if(explodedKey!=null){alert(implodeKeyNotNulErrorMsg);return;};lastImplode=new Array(3);lastImplode[0]=keyId;lastImplode[1]=imgNameImplode;lastImplode[2]=encodedUid;new Ajax.Request(document.forms[0].action+randomize(document.forms[0]),{method:'post',postBody:imgNameImplode+'=1&resort=false&ajax=true&EncodedUid='+encodedUid+additionnalParameters,onSuccess:done_imploding,onFailure:error_imploding});implodedRow=findThisRow(keyId,$(currentMusicTree));removeAllChildsOf(implodedRow);return false;}
function done_imploding(originalRequest){var keyId=lastImplode[0];Element.show("spanex_"+keyId);Element.hide("spanim_"+keyId);$("linkalb_"+keyId).onclick=$("imgex_"+keyId).onclick;}
function error_imploding(response){if(response.status==12030 || response.status==12031){implode(lastImplode[0],lastImplode[1],lastImplode[2]);}}
function randomize(form){return formChar(form)+rand()+"="+rand();}function rand(){return Math.floor(Math.random()*1000000);}

function fmt_message(message,params){if(typeof params!='object'){params=new Array(params,null);}var i=0;for(;i<params.length;i++){var param=params[i];message=message.replace(new RegExp("\\{"+i+"\\}","g"),param);}for(i=0;i<params.length;i++){param=params[i];message=message.replace(new RegExp("\\{"+i+",choice,0#([^\\|]*)\\|1#([^\\|]*)\\|1<([^\\}]*)\\}","g"),parseInt(param)==0?"$1":(parseInt(param)==1?"$2":"$3"));message=message.replace(new RegExp("\\{"+i+",choice,1#([^\\|]*)\\|1<([^\\}]*)\\}","g"),parseInt(param)==1?"$1":"$2");}return message;}
function confirmAction(form,btnName,btnValue,selectedFields,errorMessageNothingSelected,confirmText,i18nParam){var numSelected=isSomethingSelected(form,selectedFields);if(numSelected==0){alert(errorMessageNothingSelected);return;}if(typeof(confirmText)!='undefined'){if(confirm(fmt_message(confirmText,new Array(numSelected,i18nParam)))){postForm(form,btnName,btnValue);}return;}postForm(form,btnName,btnValue);}
function isSomethingSelected(form,whatToLookFor){if(typeof whatToLookFor!='object'){whatToLookFor=new Array(whatToLookFor,null);}var formElements=form.elements;var numSelected=0;for(i=0;i<whatToLookFor.length;i++){for(j=0;j<formElements.length;j++){if(formElements[j].name==whatToLookFor[i] && formElements[j].checked){numSelected++;}}}return numSelected;}
function postForm(form,btnName,btnValue){showLoading();form.action=form.action+formChar(form)+btnName+'='+btnValue;form.submit();}
var summaryReloadTimer=null;
String.prototype.trim=function(){return this.replace(/^\s+|\s+$/g,"");}
var bgmLists=new Array();var selectedValue=0;var jukeBgmType=0;var backgroundBgmType=1;var customBgmType=2;var oldBgmType=jukeBgmType;function filterBGMLists(bgmType){var bgmId,i;if(typeof bgmType=='undefined'){bgmType=$('song_list.background.type');bgmId=$('song_list.background.id');}else{bgmId=$(bgmType.id.replace('.type','.id'));}if(bgmLists[bgmId.id]==null){bgmLists[bgmId.id]=new Array();var options=bgmId.options;for(i=0;i<options.length;i++){bgmLists[bgmId.id][i]=options[i];}}if(bgmId.options.selectedIndex >= 0)selectedValue=bgmId.options[bgmId.options.selectedIndex].value;var l=bgmId.options.length;for(i=0;i<l;i++){bgmId.remove(0);}var listType=bgmType.value.toLowerCase();var count=0;var selectedIndex=0;for(i=0;i<bgmLists[bgmId.id].length;i++){if(bgmLists[bgmId.id][i].value.toLowerCase().indexOf(listType)!=-1){bgmId.options[bgmId.length]=bgmLists[bgmId.id][i];if(bgmLists[bgmId.id][i].value==selectedValue){selectedIndex=bgmId.length-1;}}}if(bgmId.length==0 ){if(bgmType.selectedIndex == customBgmType){alert(noCustomListsErrMsg);bgmType.selectedIndex=oldBgmType;filterBGMLists(bgmType);}else if ( bgmType.selectedIndex == backgroundBgmType){alert(noBackgroundListsErrMsg);bgmType.selectedIndex=oldBgmType;filterBGMLists(bgmType);}return;}oldBgmType=bgmType.selectedIndex;bgmId.selectedIndex=selectedIndex;}
function checkMaxLength(el,msg){
	var maxLength=el.getAttribute('maxlength');
	if(el.value.length > maxLength)
		{ alert(msg); 
		  el.value=el.value.substring(0,maxLength);
		}
	}
function googleAnalyticsTracking_AJAX(analyticsPaths){for(var i=0;i<analyticsPaths.length;i++){if(analyticsPaths[i]!=''&&analyticsPaths[i]!='google_analytics'){googleAnalyticsTracking(analyticsPaths[i]);}}}
function done_getJukeboxDownloads(response){if(ie && version == 6){$('JukeboxDownloads').style.width='0px';}responseArray=response.responseText.split('<div id="separator" style="display:none;"></div>');$('JukeboxDownloads').innerHTML=responseArray[0];Element.hide("loading");$("loadingBG").style.zIndex=0;Element.show('JukeboxDownloads');positionCenter('JukeboxDownloads');googleAnalyticsTracking_AJAX(responseArray.splice(1,responseArray.length-1));}

function menuBlocking(elementSelected){
var default_layer='default_layer';
var MUSICMAN_layer='MUSICMAN_layer';
var ROUTEMAN_layer='ROUTEMAN_layer';
var JUKEMAN_layer= 'JUKEMAN_layer';
var ADVANCED_layer='ADVANCED_layer';
var CONFIG_layer='CONFIG_layer';
var TOUCHTUNES_layer='TOUCHTUNES_layer';
var MUSICMAN_title='MUSICMAN';
var ROUTEMAN_title='ROUTEMAN';
var JUKEMAN_title= 'JUKEMAN';
var ADVANCED_title='ADVANCED';
var CONFIG_title='CONFIG';
var TOUCHTUNES_title='TOUCHTUNES';
if($(MUSICMAN_title)!=null){$(MUSICMAN_title).className='mainMenu';$(MUSICMAN_layer).style.display='none';}
if($(ROUTEMAN_title)!=null){$(ROUTEMAN_title).className='mainMenu';$(ROUTEMAN_layer).style.display='none';}
if($(JUKEMAN_title)!=null){$(JUKEMAN_title).className='mainMenu';$(JUKEMAN_layer).style.display='none';}
if($(ADVANCED_title)!=null){$(ADVANCED_title).className='mainMenu';$(ADVANCED_layer).style.display='none';}
if($(CONFIG_title)!=null){$(CONFIG_title).className='mainMenu';$(CONFIG_layer).style.display='none';}
if($(TOUCHTUNES_title)!=null){$(TOUCHTUNES_title).className='mainMenu';$(TOUCHTUNES_layer).style.display='none';}
$(default_layer).style.display='none';
$(elementSelected).style.display='block';
if(xHeight(elementSelected)>27){$('m2_empty_'+elementSelected).src=baseUrl+'images/m2_empty_big.gif'}
}

var loading=false;
function changeList(combobox) {
	if(loading){return;}
	loading=true
    showLoading()
	var value=combobox.value
	var groupId=value.substring(0,value.indexOf(':'))
	var subGroupId=value.substring(value.indexOf(':')+1,value.length)
	combobox.form.STYLE_BUTTON.name='STYLE_BUTTON:' + groupId;
	combobox.form.STYLE_LIST.value=subGroupId;
	combobox.form.STYLE_LIST.name='STYLE_LIST:' + groupId;
	combobox.form.submit();
}

var controllerId = -1 ;
function addToCart(songId, preType, preSelectionId, action, suffix, type){
	if(typeof suffix == 'undefined' || suffix == ''){
		suffix = "";
		completeSuffix = suffix;
	}
	else completeSuffix = "_"+suffix;
	if(typeof type == 'undefined' ){
		type = "preselection";
	}
	
	if(typeof remainingCapacity != 'undefined' && !hasRemainingCapacity(false)){
		return false;
	}
	if( $("songDisplayAction_AddToCart_"+preType+"_"+preSelectionId+"_"+songId+completeSuffix)){
		Element.hide("songDisplayAction_AddToCart_"+preType+"_"+preSelectionId+"_"+songId+completeSuffix);
	}
	if( $("songDisplayAction_AddingToCart_"+preType+"_"+preSelectionId+"_"+songId+completeSuffix)){
		Element.show("songDisplayAction_AddingToCart_"+preType+"_"+preSelectionId+"_"+songId+completeSuffix);
	}
	valueStr = "";
	if(type == "preselection"){
		valueStr = "&preType="+preType+"&preSelectionId="+preSelectionId;
	}
	else if(type == "genre"){
		valueStr = "&musicPortalGenresCurrentStyle="+preType+"&musicPortalGenresCurrentSubStyle="+preSelectionId;
	}
	
	new Ajax.Request("Music_addToCart.jsp?ajax=none&controllerId="+controllerId+"&type="+type+"&action="+action+"&songId="+songId+valueStr+"&suffix="+suffix+"&"+Math.random()+"="+Math.random(),{method:"get",onComplete:done_addToCart});
}

function done_addToCart(response){
	var responseArray=response.responseText.split('<div id="separator" style="display:none;"></div>');
	if(responseArray[2] == "musicAddToCartSuccess"){
		updateAllActions(responseArray[3].split('|'), true);
		if(responseArray[7] && $('musicCartTop'))Element.update("musicCartTop", responseArray[7]);
	}
	else if(responseArray[2] == "musicAddToCartFailed"){
		updateAllActions(responseArray[3].split('|'), false);
	}
	
	Element.update('resultMessages',responseArray[1]);
	
	addAllManagement(responseArray[4], responseArray[5], responseArray[6], 0);
}

function updateAllActions(actions, success){
	
	if(success){
		for(j = 0; j < actions.length; j++){
			ids = actions[j].split(':');
			strings = ids[1].split(',');
			for(k = 0; k < strings.length; k++){
				vals = strings[k].split('_');
				if(vals.length < 3)suffix = "";
				else suffix = "_"+vals[2];
				if( $("songDisplayAction_AddingToCart_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix)){
					Element.hide("songDisplayAction_AddingToCart_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix);
				}
				if( $("songDisplayAction_AddToCart_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix)){
					Element.hide("songDisplayAction_AddToCart_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix);
				}
				if( $("songDisplayAction_Added_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix)){
					Element.show("songDisplayAction_Added_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix);
				}
			}
		}
	}
	else{
		for(j = 0; j < actions.length; j++){
			ids = actions[j].split(':');
			strings = ids[1].split(',');
			for(k = 0; k < strings.length; k++){
				vals = strings[k].split('_');
				if(vals.length < 3)suffix = "";
				else suffix = "_"+vals[2];
				if( $("songDisplayAction_AddingToCart_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix)){
					Element.hide("songDisplayAction_AddingToCart_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix);
				}
				if( $("songDisplayAction_AddToCart_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix)){
					Element.show("songDisplayAction_AddToCart_"+vals[0]+"_"+vals[1]+"_"+ids[0]+suffix);
				}
			}
		}
	}
}

function addManyToCart(songIds, preType, preSelectionId, action, suffix,type){
	if(typeof remainingCapacity != 'undefined' && !hasRemainingCapacity(true)){
		return false;
	}
	if(typeof type == 'undefined' ){
		type = "preselection";
	}
	if(typeof suffix == 'undefined' || suffix == ''){
		suffix = "";
		completeSuffix = suffix;
	}
	else completeSuffix = "_"+suffix;
	// don't show these elements while adding
	if($('addAll_'+preType+"_"+preSelectionId+completeSuffix) )Element.hide('addAll_'+preType+"_"+preSelectionId+completeSuffix);
	if($('addAllNew_'+preType+"_"+preSelectionId+completeSuffix) )Element.hide('addAllNew_'+preType+"_"+preSelectionId+completeSuffix);
	if($('addAllRemaining_'+preType+"_"+preSelectionId+completeSuffix) )Element.hide('addAllRemaining_'+preType+"_"+preSelectionId+completeSuffix);
	if($('addAllAdded_'+preType+"_"+preSelectionId+completeSuffix) )Element.hide('addAllAdded_'+preType+"_"+preSelectionId+completeSuffix);
	Element.show('addAllAdding_'+preType+"_"+preSelectionId+completeSuffix);
		
	idsString = "" ;
	for(k=0;k<songIds.length;k++){
		
		if( $("songDisplayAction_AddToCart_"+preType+"_"+preSelectionId+"_"+songIds[k]+completeSuffix)){
			Element.hide("songDisplayAction_AddToCart_"+preType+"_"+preSelectionId+"_"+songIds[k]+completeSuffix);
		}
		if( $("songDisplayAction_AddingToCart_"+preType+"_"+preSelectionId+"_"+songIds[k]+completeSuffix)){
			Element.show("songDisplayAction_AddingToCart_"+preType+"_"+preSelectionId+"_"+songIds[k]+completeSuffix);
		}
		idsString += songIds[k];
		if(k < songIds.length-1) idsString +=",";
		
	}
	new Ajax.Request("Music_addToCart.jsp?ajax=none&controllerId="+controllerId+"&type="+type+"&action="+action+"&preType="+preType+"&preSelectionId="+preSelectionId+"&suffix="+suffix+"&"+Math.random()+"="+Math.random(),{method:"post", postBody:"&songIds="+idsString, onComplete:done_addManyToCart});
}

function done_addManyToCart(response){
	var responseArray=response.responseText.split('<div id="separator" style="display:none;"></div>');
	numAdded = 0;
	if(responseArray[2] == "musicAddToCartSuccess"){
		actions = responseArray[3].split('|');
		updateAllActions(actions, true);
		numAdded = actions.length;
		if(responseArray[7] && $('musicCartTop'))Element.update("musicCartTop", responseArray[7]);
	}else if(responseArray[2] == "musicAddToCartFailed"){
		actions = responseArray[3].split('|');
		updateAllActions(actions, false);
	}
	Element.update('resultMessages',responseArray[1]);
	addAllManagement(responseArray[4], responseArray[5], responseArray[6], numAdded);

	if(add_more_block_content!=null && add_more_block!=null){
		add_more_block.innerHTML=add_more_block_content;
		add_more_block_content=null;
	}
}

function addAllManagement(pteId, pseId, suffix, num){
	showAllPreToCart(pteId,pseId,num, suffix)
}

var selectedMenu=-1;
function showMusicPortalSubMenuAfterTimeout() {
	if (selectedMenu != -1)
	{
		showSelectedPicks('musicSylviesPicks_title_subMenu_'+selectedMenu, 'musicSylviesPicks_title_subMenus','menu')
	}
}

var insideMenu=0;
var currentMenuState=0;
var timeoutVar;
function removeMusicPortalSubMenuAfterTimeout() {
	insideMenu = 0;
	timeoutVar = setTimeout('checkMusicPortalSubMenu()',3000);
}

function isInsideMusicPortalSubMenu() {
	insideMenu = 1;
	currentMenuState = 1;
	clearTimeout(timeoutVar);
}

function checkMusicPortalSubMenu() {
	if (insideMenu == 0 && currentMenuState == 1 && selectedMenu == -1 )
	{
		showSelectedPicks('', 'musicSylviesPicks_title_subMenus','menu');
		currentMenuState = 0;
	}
}

function showSelectedPicks(id,theClass, upperId){
	els=document.getElementsByClassName(theClass, upperId);
	var nodes=$A(els);
	nodes.each(function(node){
		if(node.id == id){
			Element.show(node.id);
			childs=$(node).childNodes;
			var nodes2=$A(childs);
			nodes2.each(function(node2){
				if(typeof node2!= "undefined" && typeof node2.id != "undefined" && node2.id != ""){
					Element.show(node2.id);
				}
			});
		}else{
			Element.hide(node.id);
		}
	});
}

function removeParentMusicPortalMenu(total){
	// reset the menu id
	selectedMenu = -1;
	for (i=0; i < total ; i++)
	{
		if(Element.hasClassName("parent_"+i,"current")){
				Element.removeClassName("parent_"+i,"current");
		}
	}
}

function showParentMusicPortalMenu(id){
	// set the menu id
	selectedMenu = id;
	if(!Element.hasClassName("parent_"+id,"current")){
		Element.addClassName("parent_"+id,"current");
	}
}

function showSelectedPicks2(id, theArray, defaultActiveTab){
	//we first test if its completely loaded
	for(i=0;i<theArray.length;i++){
		if(!$(theArray[i]+"_value")) {
			alert(theArray[i]+"_value");
			return false;
		}
	}
	
	for(i=0; i < theArray.length ; i++){
		var titleId=theArray[i]+"_title";
		var valueId=theArray[i]+"_value";
		if(theArray[i] == id){
			Element.show(valueId);
			if(!Element.hasClassName(titleId,"current")){
				Element.addClassName(titleId,"current");
			}
			childs=$(titleId).childNodes;
			nodes=$A(childs);
			nodes.each(function(node){
				if(node.nodeName == "A"){
					if(!Element.hasClassName(node,"current")){
						Element.addClassName(node,"current");
					}
				}
			});
			// Activate the default tab, if no tab is selected
			if(typeof defaultActiveTab != 'undefined'){
				if(!bottomAccordion[bottomAccordion.length-1].showAccordion){
					bottomAccordion[bottomAccordion.length-1].activate($$('#'+valueId+' .accordion_toggle')[defaultActiveTab]);
				}
			}
		}else{
			Element.hide(valueId);
			if(Element.hasClassName(titleId,"current")){
				Element.removeClassName(titleId,"current");
			}
			childs=$(titleId).childNodes;
			var nodes=$A(childs);
			nodes.each(function(node){
				if(node.nodeName == "A"){
					if(Element.hasClassName(node,"current")){
						Element.removeClassName(node,"current");
					}
				}
			});
		}
	}
}

function showAllPreToCart(preTypeName, id, numAddToCartTotal, suffix){
	
	if(typeof suffix == 'undefined' || suffix == ''){
		suffix = "";
		completeSuffix = suffix;
	}
	else completeSuffix = "_"+suffix;
	
	if(typeof numAddToCartTotal == 'undefined')numAddToCartTotal=0;
	var numAddToCart = getNumberSongsToAdd(preTypeName, id,completeSuffix);
	if(typeof numAddToCartTotal == 'undefined')numAddToCartTotal=0;
	
	if($('addAll_'+preTypeName+"_"+id+completeSuffix) )Element.hide("addAll_"+preTypeName+"_"+id+completeSuffix);
	if($("addAllRemaining_"+preTypeName+"_"+id+completeSuffix) )Element.hide("addAllRemaining_"+preTypeName+"_"+id+completeSuffix);
	if($("addAllAdded_"+preTypeName+"_"+id+completeSuffix) )Element.hide("addAllAdded_"+preTypeName+"_"+id+completeSuffix);
	if($("addAllAdding_"+preTypeName+"_"+id+completeSuffix) )Element.hide("addAllAdding_"+preTypeName+"_"+id+completeSuffix);
	
	if(numAddToCartTotal != 0){
		if($("addAllAdded_"+preTypeName+"_"+id+completeSuffix) ){
			Element.update("addAllAdded_"+preTypeName+"_"+id+completeSuffix+"_text_value",getSongAddedString(numAddToCartTotal));
			Element.show("addAllAdded_"+preTypeName+"_"+id+completeSuffix);
		}
	}
	
	if(numAddToCart == 0 && $("addAllRemaining_"+preTypeName+"_"+id+completeSuffix)){
		numAddToCart = getNumberSongsToAdd(preTypeName, id, completeSuffix, true);
		if(numAddToCart != 0){
			Element.update("addAllRemaining_"+preTypeName+"_"+id+completeSuffix+"_text_value",getSongRemainingString(numAddToCart));
			Element.show("addAllRemaining_"+preTypeName+"_"+id+completeSuffix);
		}
	}else if(numAddToCart != 0){
		if($("addAll_"+preTypeName+"_"+id+completeSuffix) ){
			Element.show("addAll_"+preTypeName+"_"+id+completeSuffix);
		}
	}
	
}

function getSongRemainingString(value){
	var valStr = new String(value);
	if(value == 1){
		valStr = $('song_template_remaining').innerHTML;
	}else{
		var str = $('songs_template_remaining').innerHTML;
		valStr = str.replace('TheValue',new String(value) );
	}
	return valStr;
}

function getSongAddedString(value){
	valStr=new String(value);
	if(value == 1){
		valStr += $('song_template_added').innerHTML;
	}else{
		valStr += $('songs_template_added').innerHTML;
	}
	return valStr;
}

function getNumberSongsToAdd(preTypeName,id,suffix, all){
	var num=0;
	if(typeof all == 'undefined') all = false;
	if(typeof PteScroller != 'undefined' && typeof PteScroller[preTypeName] != 'undefined' && typeof PteScroller[preTypeName][id] != 'undefined' && suffix == ""){	
		var visiblePage = getShowingScrollingPage(preTypeName, id);
		for(i=0; i< PteScroller[preTypeName][id].block.length; i++){
			if(all || visiblePage == i){
				var els=getElementsByClassName(PteScroller[preTypeName][id].block[i],"songDisplayAction_AddToCart");
				num += countNumberSongsToAdd(els,preTypeName,id );
			}
		}
	}	
	else{
		var node = $('addAll_'+preTypeName+"_"+id+suffix);
		while (!Element.hasClassName(node.id, 'addMaster') && typeof node.parentNode != 'undefined'){
			node = node.parentNode;
			while(node.id == ""){
				node = node.parentNode;
			}
		}
		
		if(all || suffix == "_album"){
			var els = getElementsByClassName($(node.id),"songDisplayAction_AddToCart");
		}
		else{
			var nodesList = $(node.id).childNodes;
			for(i=0;i<nodesList.length;i++){
				if(typeof nodesList[i].id != 'undefined' && nodesList[i].id.indexOf(node.id) != -1 && Element.visible(nodesList[i])){
					var els = getElementsByClassName($(nodesList[i].id ),"songDisplayAction_AddToCart");
					break;
				}
			}
		}
		
		num = countNumberSongsToAdd(els, preTypeName, id);
	}
	
	return num;
}

function countNumberSongsToAdd(els, preTypeName, pseId){
	var num=0;
	var nodes=$A(els);
	nodes.each(function(node){
		if(node.id.indexOf("songDisplayAction_AddToCart_"+preTypeName+"_"+pseId) != -1){
			if(Element.visible(node.id)){
				num++;
			}
		}
	});
	return num;
}

function getShowingScrollingPage(preTypeName, id){
	
	if(typeof PteScroller != 'undefined' && typeof PteScroller[preTypeName] != 'undefined' && typeof PteScroller[preTypeName][id] != 'undefined'){
		var visiblePage = 0;
		for(i=0 ; i < PteScroller[preTypeName][id].block.length ; i++){
			visiblePage=i;
			if(typeof PteScroller[preTypeName][id].goto2 == "undefined" || PteScroller[preTypeName][id].goto2 == i){
				break;
			}
		}
	}
	
	return visiblePage ;
}

var add_more_block_content=null;
var add_more_block=null;
function addBlockToCart(preTypeName, pseId, all, action, suf, id, topNum, genre){
	if(typeof genre!='undefined'){
		add_more_block=$('add_more_'+genre+'_'+preTypeName+'_'+pseId);
		if(add_more_block){
			add_more_block_content=add_more_block.innerHTML;
			add_more_block.innerHTML='Adding... Please wait.';
		}
	}
	var els=new Array();
	if(typeof id!='undefined'){
		if(all){
			if(typeof topNum!='undefined'){
				// Load missing pages, if any
				var n=0;
				for (i=0;n<topNum;i++){
					if($(id+"_"+i+"_pagination")){
						if(!$(id+"_"+i)){
							new Insertion.Top($(id), '<div id="'+id+'_'+i+'" style="display:none"><div id="'+id+'_'+i+'_need_load" style="height:334px"><div class="ajax-loader-genre">Loading...</div></div></div>');
							new Ajax.Request("MusicPortalGenres_songsAjax.jsp?ajax=none&page="+(i+1)+"&"+Math.random()+"="+Math.random(),{method:"get", onComplete:done_changePage});
						}
						n+=15;
					}else{
						break;
					}
				}
				n=0;
				for(i=0;n<topNum;i++){
					while($(id+"_"+i+"_need_load")){
						// Wait for page to load by calling myself every 500ms, using JS closure
						setTimeout(function(){addBlockToCart(preTypeName, pseId, all, action, suf, id, topNum);},500);
						return;
					}
					if (!$(id+"_"+i)){break;}
					var ar=getElementsByClassName($(id+"_"+i),"songDisplayAction_AddToCart");
					els.push(ar);
					n+=ar.length;
				}
			}else{
				for(i=0;$(id+"_"+i);i++){
					els.push(getElementsByClassName($(id+"_"+i),"songDisplayAction_AddToCart"));
				}			
			}
		}else{
			els.push(getElementsByClassName($(id+"_"+lastPageSelectedForChangePage),"songDisplayAction_AddToCart"));
		}
	}
	else{
		if(all){
			for(i=0;i<PteScroller[preTypeName][pseId].block.length;i++){
				els.push(getElementsByClassName(PteScroller[preTypeName][pseId].block[i],"songDisplayAction_AddToCart"));
			}
		}else{
			visiblePage=getShowingScrollingPage(preTypeName,pseId);
			els.push(getElementsByClassName(PteScroller[preTypeName][pseId].block[visiblePage],"songDisplayAction_AddToCart"));
		}
	}
	addAllToCart(els, true, preTypeName, pseId, action, suf, topNum)
}

function addBlock2Cart(preTypeName, pseId, suf, id, action){
	els=new Array();
	els.push(getElementsByClassName($(id),"songDisplayAction_AddToCart"));
	addAllToCart(els, true, preTypeName, pseId, action, suf)
}

function getElementsByClassName(truc,className) {
	var classArray=new Array();
	if(truc ){
		var elts=truc.getElementsByTagName('*');
		for(var j=0; j<elts.length; ++j){
			if(elts[j].className != '' && elts[j].className.split(' ').inArray(className)){
				classArray.push(elts[j]);
			}
		}
	
	}

	return classArray;
}

Array.prototype.inArray=function(v){for(var a=0;a<this.length;++a){if(this[a]==v){return true;}}return false;};

function addAccoBlockToCart(preTypeName, id, all, action){
	els=new Array();
	if(all){
		els.push(document.getElementsByClassName("songDisplayAction_AddToCart","allMusicVerticals_column_item_"+preTypeName +"_"+ id));
		els.push(document.getElementsByClassName("songDisplayAction_AddToCartNew","allMusicVerticals_column_item_"+preTypeName +"_"+ id));
		addAllToCart(els, true, preTypeName, id, action);
	}
}

function addNewAccoBlockToCart(preTypeName, id, all, action){
	els=new Array();
	if(all){
		els.push(document.getElementsByClassName("songDisplayAction_AddToCartNew","allMusicVerticals_column_item_"+preTypeName +"_"+ id));
		// we don't execute the change if no element are found
		if (els.length > 0)
		{
			var nodes = $A(els[0]);
			if (nodes.length > 0) 
			{
				addAllToCart(els, true, preTypeName, id, action);
			}
		}
	}
}

function addAllToCart(elements, visible, preTypeName, id, action, suffix, topMax){
	songIds=new Array();
	topNum = 0
	for(i=0;i< elements.length && (typeof topMax == 'undefined' || topNum < topMax);i++){
		var nodes = $A(elements[i]);
		nodes.each(function(node){
			var test=elements[i];
			if(Element.visible(node.id)){
				var valueArray = node.id.split("_");
				songIds.push(valueArray[4]);
			}
			topNum++;
			if(topNum >= topMax) throw $break;
		});
	}
	if(songIds.length > 0){
		addManyToCart(songIds, preTypeName, id, action, suffix);
	}else{
		if(add_more_block_content!=null && add_more_block!=null){
			add_more_block.innerHTML=add_more_block_content;
			add_more_block_content=null;
		}
	}
}

var lastPageSelectedForChangePage;
function changePage(page,id,el,preTypeName,preId,numAddToCartTotal,suffix){
	if(Element.visible(id+"_"+lastPageSelectedForChangePage)){Element.hide(id+"_"+lastPageSelectedForChangePage);}
	if($(id+"_"+page)){
		Element.show(id+"_"+page);
		changePagePhase2(page,id,el,preTypeName,preId,numAddToCartTotal,suffix);
	}else{
		new Insertion.Top($(id), '<div id="'+id+'_'+page+'" style="display:block"><div id="'+id+'_'+page+'_need_load" style="height:334px"><div class="ajax-loader-genre">Loading...</div></div></div>');
		setTimeout(function(){new Ajax.Request("MusicPortalGenres_songsAjax.jsp?ajax=none&page="+(page+1)+"&"+Math.random()+"="+Math.random(),{method:"get",onComplete:done_changePage});},10);
		setTimeout(function(){changePagePhase2(page,id,el,preTypeName,preId,numAddToCartTotal,suffix)},200);
	}
	return false;
}
function changePagePhase2(page,id,el,preTypeName,preId,numAddToCartTotal,suffix){
	Element.removeClassName(id+"_"+lastPageSelectedForChangePage+"_pagination", "pager_highlight");
	if(!Element.hasClassName(id+"_"+page+"_pagination","pager_highlight")){Element.addClassName(id+"_"+page+"_pagination","pager_highlight");}
	lastPageSelectedForChangePage=page;
	el.blur();
	showAllPreToCart(preTypeName,preId,numAddToCartTotal,suffix);
	managePagination(id,page);
}
function done_changePage(response){
	if(response.responseText.search('ControllerException')!=-1){window.location='Error.jsp';return;}
	var responseArray=response.responseText.split('<div id="separator"></div>');
	var el='more_songs_'+responseArray[1].trim()+'_'+responseArray[2].trim()+'_'+responseArray[3].trim()+'_'+responseArray[4].trim();
	if($(el+'_need_load')){
		var p=responseArray[0].indexOf(el);if(p==-1){return;}
		p=responseArray[0].indexOf('>',p);if(p==-1){return;}
		p++;
		var p2=responseArray[0].indexOf('EO-'+el,p);if(p2==-1){return;}
		p2-=5;
		var html=responseArray[0].substr(p,p2-p);
		$(el).update(html);
	}
}

var pagination = new Array(); 
var previousIndex = new Array();
var nextIndex = new Array(); 
function initializePagination(key, numPages, numPagesShowing, actualPage){
	pagination[key] = new Array(); 
  	pagination[key]['numPages'] = numPages;
   	pagination[key]['numPagesShowing'] = numPagesShowing;
   	pagination[key]['actualPage'] = actualPage;
	managePagination(key,actualPage);
	lastPageSelectedForChangePage=0;
}

var visiblePagination=Array();
function managePagination(key,showPage){
	var actualPage = new Number(pagination[key]['actualPage']);
	var lowerValue = new Number(pagination[key]['lowerValue']);
	var higherValue = new Number(pagination[key]['higherValue']);
    var numPages = new Number(pagination[key]['numPages']);
    var numPagesShowing = new Number(pagination[key]['numPagesShowing']);
	if(isNaN(showPage)){
		if(showPage == 'previous'){
			if(actualPage != 0){
				actualPage = actualPage-1;
				pagination[key]['actualPage'] = actualPage;
			}
		}else if(showPage == 'next'){
			if(actualPage != numPages-1){
				actualPage = actualPage+1;
				pagination[key]['actualPage'] = actualPage;
			}
		}
	}else{
		actualPage = new Number(showPage);
		pagination[key]['actualPage'] = actualPage;
	}
	if(actualPage > 0){
		previousIndex[key]=actualPage-1;
	}else{
		previousIndex[key]=0;
	}
	if(actualPage < numPages-1){
		nextIndex[key]=actualPage+1;
	}else{
		nextIndex[key]=numPages-1;
	}
    if(isNaN(lowerValue) || isNaN(higherValue) || showPage <= lowerValue || showPage >= higherValue){    
		lowerValue = 0;
		higherValue = numPages-1;
    	var lowerBuf = 0;
	    var higherBuf = 0;
	    if(numPagesShowing%2 != 0){
	        lowerBuf = Math.floor(numPagesShowing/2);
	        higherBuf = Math.floor(numPagesShowing/2);
	    }else{
	        lowerBuf = Math.floor(numPagesShowing/2)-1;
	        higherBuf = Math.floor(numPagesShowing/2);
	    }
	    if(actualPage - lowerBuf > lowerValue){
	        lowerValue = actualPage-lowerBuf;
	    } 
	    if(actualPage + higherBuf < higherValue){
	        higherValue = actualPage + higherBuf;
	    } 
	    if(higherValue > numPages-1){
	   	 	higherValue = numPages-1;
	   	}
	    if(lowerValue < 0){
	    	lowerValue = 0;
	    }
	   
	   	if(higherValue - lowerValue != numPagesShowing-1 && higherValue - (numPagesShowing-1) >= 0){
	    	lowerValue = higherValue - (numPagesShowing-1);
		}else if(higherValue - lowerValue != numPagesShowing-1 && lowerValue + (numPagesShowing-1) <= numPages-1){
	    	higherValue = lowerValue + (numPagesShowing-1);
	    } 
	   
	    if($(key+"_"+"somePrevious_pagination")){
	    	Element.hide(key+"_somePrevious_pagination");
	    	if(lowerValue > 0){
	    		Element.show(key+"_"+"somePrevious_pagination");
	    	}
	    }
		if($(key+"_"+"someNext_pagination")){
			Element.hide(key+"_someNext_pagination");
			if(higherValue < numPages-1){
				Element.show(key+"_"+"someNext_pagination");
			}
		}

		pagination[key]['lowerValue'] = lowerValue;
		pagination[key]['higherValue'] = higherValue;

		if(typeof visiblePagination[key]!='undefined'){
			while(visiblePagination[key].length>0){
				Element.hide(visiblePagination[key].pop());
			}
		}
		if(lowerValue<=higherValue){
			visiblePagination[key]=Array();
			for(pageCount=lowerValue;pageCount<=higherValue;pageCount++){
				var el=$(key+"_"+pageCount+"_pagination");
				if(el){
					Element.show(el);
					visiblePagination[key].push(el);
				}
			}
		}
	}
}

function showMainDetails(songId, preType, preSelectionId, contentType){
	Element.show("loading");
	positionCenter("loading");
	var ajaxString = "&songId="+songId;
	if(typeof preType != 'undefined' && preType > 0 )
		ajaxString += "&preType="+preType;
	if(typeof preSelectionId != 'undefined' && preSelectionId > 0 )
	 	ajaxString += "&preSelectionId="+preSelectionId;
	if(typeof contentType != 'undefined' && contentType > 0 )
	 	ajaxString += "&musicPortalDetailsAlbumContentType="+contentType;
	var url="SongsByCriteriaV2_mainDetailsAjax.jsp?ajax=none&action=ajaxSongsByCriteriaV2_mainDetails"+ajaxString+"&"+Math.random()+"="+Math.random();
	new Ajax.Request(url,{method:"get",onComplete:done_showMainDetails});
}

function highLightSong(newId,oldId){if(typeof(oldId)!="undefined"){els=getElementsByClassName($(oldId),"pick-topMain");Element.removeClassName(els[0],"pick-topMain");Element.addClassName(els[0],"pick-top");els=getElementsByClassName($(oldId),"pick-bottomMain");Element.removeClassName(els[0],"pick-bottomMain");Element.addClassName(els[0],"pick-bottom");els=getElementsByClassName($(oldId),"pick-middleMain");Element.removeClassName(els[0],"pick-middleMain");Element.addClassName(els[0],"pick-middle");}els=getElementsByClassName($(newId),"pick-top");Element.removeClassName(els[0],"pick-top");Element.addClassName(els[0],"pick-topMain");els=getElementsByClassName($(newId),"pick-bottom");Element.removeClassName(els[0],"pick-bottom");Element.addClassName(els[0],"pick-bottomMain");els=getElementsByClassName($(newId),"pick-middle");Element.removeClassName(els[0],"pick-middle");Element.addClassName(els[0],"pick-middleMain");}
var currentValuesArray=new Array();function done_showMainDetails(response){var result = response.responseText.search('ControllerException');if (result != -1) {window.location = 'Error.jsp';}var responseArray=response.responseText.split('<div id="separator"></div>');Element.update('SongsByCriteriaV2_mainDetails',response.responseText);Element.hide("loading");highLightSong('song_'+responseArray[1].trim()+'_'+responseArray[2].trim()+'_'+responseArray[3].trim(),'song_'+currentValuesArray[0]+'_'+currentValuesArray[1]+'_'+currentValuesArray[2]);highLightSong('song_'+responseArray[1].trim()+'_0_'+responseArray[3].trim(),'song_'+currentValuesArray[0]+'_0_'+currentValuesArray[2]);currentValuesArray[0]=responseArray[1].trim();currentValuesArray[1]=responseArray[2].trim();currentValuesArray[2]=responseArray[3].trim();}

var prefetch_data_index=0;function prefetch_data_next(r){if(prefetch_data_index<prefetch_data.length){prefetch_data_index++;new Ajax.Request(prefetch_data[prefetch_data_index-1],{method:'get',onSuccess:prefetch_data_next,onFailure:prefetch_data_previous});}}function prefetch_data_previous(r){prefetch_data_index--;prefetch_data_next();}

function logPresel(music_id){new Ajax.Request(baseUrl+"PreLog.jsp?id="+music_id+"&"+rand()+"="+rand(),{method:'get'});}

var sortId;
function ajaxSort(url,id){sortId=id;url=url.replace('&ajax=none',"");url=url.replace('&action=ajaxSort',"");new Ajax.Request(url+"&ajax=none&action=ajaxSort",{method:"get",onSuccess:Done_ajaxSort,onFailure:Failure_ajaxSort});}
function Done_ajaxSort(response){divObject = $(sortId).parentNode;Element.remove(sortId);new Insertion.Bottom(divObject,response.responseText);}
function Failure_ajaxSort(response){}

var headTop = -1;
function saveHeadPos(){if($("headStart")){headTop=$("headStart").offsetTop;}}
function processScroll(){if(headTop<0){saveHeadPos();}if(headTop>=0){var theTop=xScrollTop();if(theTop>headTop){$("floatingHeader1").style.position='relative';$("floatingPreHeader1").style.position='relative';$("floatingHeader1").style.top=(theTop-headTop)+'px';$("floatingPreHeader1").style.top=(theTop-headTop)+'px';}else{$("floatingHeader1").style.top='-2px';$("floatingPreHeader1").style.top='-2px';}}}

function xAddEventListener(e,eT,eL,_4){if(!(e=$(e))){return;}eT=eT.toLowerCase();if(e.addEventListener){e.addEventListener(eT,eL,_4);}else{if(e.attachEvent){e.attachEvent("on"+eT,eL);}else{eval("e.on"+eT+"=eL");}}}
function addLoadEvent(event){var oldEvent=window.onload;if(typeof window.onload!="function"){window.onload=event;}else{window.onload=function(){oldEvent();event();};}}

function nextTip(){new Ajax.Request('_tipsAjax.jsp?p='+escape(currentPageURL.substring(currentPageURL.lastIndexOf('/')+1))+'&ajax=none&'+rand()+'='+rand(),{method:'get',onSuccess:done_next_tip,onFailure:error_next_tip});}
function done_next_tip(originalRequest){$('tipMessage').innerHTML=originalRequest.responseText;originalRequest.responseText.evalScripts();}
function error_next_tip(response){if(response.status==12030||response.status==12031){nextTip();}}

function fetchSongsFromGenre(genre, prefix, suffix){
	if(typeof suffix != 'undefined'){suffix = '_'+suffix;}
	var els = getElementsByClassName($(prefix+'_'+genre+suffix),"wrap-table");
	var nodes=$A(els);
	nodes.each(function(node){
		if(node.nodeName == 'DIV' && Element.hasClassName(node.id,'active-tab-body') && Element.hasClassName(node.parentNode.id,'active-tab-body')){
			values = node.id.split("_");
			fetchGenreStyleSongs(genre, values[2], values[3], prefix);
		}
	});
}

function fetchSongsFromStyle(genre, style, prefix){
	valueStr = prefix+'_'+genre+'_'+style;
	var els = getElementsByClassName($(prefix+'_'+genre+'_'+style+"_value"),"wrap-table");
	var nodes=$A(els);
	nodes.each(function(node){
		if(node.nodeName == 'DIV' && Element.hasClassName(node.id,'active-tab-body')){
			fetchGenreStyleSongs(genre, style, node.id.substr(valueStr.length+1,node.id.lastIndexOf("_")-(valueStr.length+1)), prefix);
		}
	});
}

var lastLoadedGenreStyleSongsId=null;
function fetchGenreStyleSongs(genre, style, subStyle, prefix){
	if(lastLoadedGenreStyleSongsId!=null){
		$(lastLoadedGenreStyleSongsId+'_value').innerHTML='';
	}
	if($(prefix+'_'+genre+'_'+style+'_'+subStyle+"_value").innerHTML.length <= 1){
		new Ajax.Request("MusicPortalGenres_songsAjax.jsp?ajax=none&musicPortalGenresCurrentGenre="+genre+"&musicPortalGenresCurrentStyle="+style+"&musicPortalGenresCurrentSubStyle="+subStyle+"&"+Math.random()+"="+Math.random(),{method:"get",onComplete:done_fetchGenreStyleSongs});
		$(prefix+'_'+genre+'_'+style+'_'+subStyle+"_value").innerHTML="<div class='ajax-loader-genre'>Loading...</div>";
	}else{
		// We still need to call this URL, so that the controller changes it's active genre & style.
		new Ajax.Request("MusicPortalGenres_songsAjax.jsp?ajax=none&musicPortalGenresCurrentGenre="+genre+"&musicPortalGenresCurrentStyle="+style+"&musicPortalGenresCurrentSubStyle="+subStyle+"&"+Math.random()+"="+Math.random(),{method:"get"});
	}
	lastLoadedGenreStyleSongsId=prefix+'_'+genre+'_'+style+'_'+subStyle;
}

function done_fetchGenreStyleSongs(response){
	var responseArray = response.responseText.split('<div id="separator"></div>');
	var prefix = 'musicPortalGenres';
	var genre = responseArray[1].trim();
	var style = responseArray[2].trim();
	var subStyle = responseArray[3].trim();
	$(prefix+'_'+genre+'_'+style+'_'+subStyle+"_value").innerHTML = responseArray[0];
	responseArray[0].evalScripts();
}

function alignGenreMenu(id){
	if($("drop-menu_"+id) && !Element.visible("drop-menu_"+id)){
		var total=0;
		var width=xWidth($("tabsK_genre_"+id));
		if (width>650 || width==0) {
			setTimeout(function(){alignGenreMenu(id)}, 100);
			return;
		}
		nodes=$("tabsK_tabmenu_"+id).childNodes
		childs=$A(nodes);
		childs.each(function(node){
			if(node.nodeName=='LI'){
				childrens=$A(node.childNodes);
				childrens.each(function(children){
					if(children.nodeName=='A'){
						var width1=$(children.id).offsetWidth;
						var width2=xWidth($(children.id));
						total+=Math.max(width1,width2);
						if(total>width){
							Element.show("drop-menu_"+id);
							Element.remove(node);
							node.className='item '+node.className;
							node.innerHTML=node.innerHTML.replace('|','');
							$("drop-menu_"+id+"_ul").insertBefore(node,$("drop-menu_"+id+"_shadow"));
						}
					}
				});
			}
		});
	}
}

if(browser=='Opera'){window.onunload=function(){try{var headElement=document.getElementsByTagName("head")[0];if(headElement&&headElement.innerHTML)headElement.innerHTML+="<meta http-equiv=\"refresh\" content=\"1\">";}catch(e){}};}

function get_form_elements_like(string){var results=Array();for(var i=0;i<document.forms[0].elements.length;i++){var el=document.forms[0].elements[i];if(el.name.indexOf(string)!=-1){results.push(el);}}return results;}

function pwd2text(input){try{var input2=input.cloneNode(false);input2.type='text';input2.onfocus=function(){};input2.onblur=function(){text2pwd(input2);};input.parentNode.replaceChild(input2,input);input2.focus();}catch(e){}}
function text2pwd(input){try{var input2=input.cloneNode(false);input2.type='password';input2.onblur=function(){};input2.onfocus=function(){pwd2text(input2);};input.parentNode.replaceChild(input2,input);}catch(e){}}

function showSchematicAgreement(doc_id, doc_url, doc_ga_code){$('agreement_document_id').value=doc_id;$('agreement_document_url').value=doc_url;$('agreement_document_gacode').value=doc_ga_code;hideCombos(true);showLoadingBG(false);$("schematic_agreement").style.zIndex=99;positionCenter("schematic_agreement");$('schematic_agreement').scrollTop=0;Element.show("schematic_agreement");positionCenter("schematic_agreement");}
function sendAgreement(){var doc_id=$('agreement_document_id').value;new Ajax.Request('Documentation.jsp',{postBody:'agree_doc_id='+doc_id,onSuccess:function(t){hideLoading();var ga_code=$('agreement_document_gacode').value;if($('doc_url_name_'+doc_id)){$('doc_url_name_'+doc_id).onclick=ga_code;}if($('doc_url_'+doc_id)){$('doc_url_'+doc_id).onclick=ga_code;}if($('doc_url_html_'+doc_id)){$('doc_url_html_'+doc_id).onclick=ga_code;}var w=window.open($('agreement_document_url').value);if(w){eval(ga_code);}Element.hide('schematic_agreement');}});}

function getSiblingByTagName(el,tagName,direction){if(direction=='previous'){if(!el.previousSibling){return null;}el=el.previousSibling;while(el.previousSibling&&(!el.tagName||el.tagName.toUpperCase()!=tagName.toUpperCase())){el=el.previousSibling;}}else{if(!el.nextSibling){return null;}el=el.nextSibling;while(el.nextSibling&&(!el.tagName||el.tagName.toUpperCase()!=tagName.toUpperCase())){el=el.nextSibling;}}return el;}
function getParentByTagName(el,tagName){while(el.parentNode&&(!el.tagName||el.tagName.toUpperCase()!=tagName.toUpperCase())){el=el.parentNode;}return el;}

var customButtons=new Array();var oldResType=0;function filterCustomButtons(resType){if(!$('pptt_custom_button_event.graphic.res_type')){return;}var resId,i;if(typeof resType=='undefined'||!resType.id){resType=$('pptt_custom_button_event.graphic.res_type');resId=$('pptt_custom_button_event.graphic.res_id');}else{resId=$(resType.id.replace('.res_type','.res_id'));}if(customButtons[resId.id]==null){customButtons[resId.id]=new Array();var options=resId.options;for(i=0;i<options.length;i++){customButtons[resId.id][i]=options[i];}}var customButtonSelectedValues=0;if(resId.options.selectedIndex>=0){customButtonSelectedValues=resId.options[resId.options.selectedIndex].value;}var l=resId.options.length;for(i=0;i<l;i++){resId.remove(0);}var listType=resType.value.toLowerCase();var count=0;var selectedIndex=0;for(i=0;i<customButtons[resId.id].length;i++){if(customButtons[resId.id][i].value.toLowerCase().indexOf(listType)!=-1){resId.options[resId.length]=customButtons[resId.id][i];if(customButtons[resId.id][i].value==customButtonSelectedValues){selectedIndex=resId.length-1;}}}if(resId.length==0){if(oldResType!=0){alert('No custom buttons are currently defined for the selected graphics type.');}resType.selectedIndex=oldResType;filterCustomButtons(resType);return;}oldResType=resType.selectedIndex;resId.selectedIndex=selectedIndex;}
addLoadEvent(filterCustomButtons);